# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    ChromatogramAutoScaleType,
    ChromatogramPeakLabelType,
    CurveFitOrigin,
    CurveFitType,
    CurveFitWeighting,
    GridExportMode,
    InstrumentType,
    IntegratorType,
    INumericCustomFormat,
    MethodEditTaskMode,
    OutlierColumns,
    PlotTitleElement,
    Properties,
    QualifierInfoLabelType,
    ScanType,
)
from .Compliance import IDataStorage

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration

class CalCurveConfiguration:  # Class
    AssistantDisabledPointColor: System.Drawing.Color  # static
    AssistantDisabledPointLineColor: System.Drawing.Color  # static
    AssistantPointColor: System.Drawing.Color  # static
    AssistantPointLineColor: System.Drawing.Color  # static
    AutoScaleToEnabledPoints: bool  # static
    AxisTitleConcentration: str  # static # readonly
    AxisTitleISTDResponse: str  # static # readonly
    AxisTitleRelativeConcentration: str  # static # readonly
    AxisTitleRelativeResponse: str  # static # readonly
    AxisTitleResponse: str  # static # readonly
    BackColor: System.Drawing.Color  # static
    CCFillColor: System.Drawing.Color  # static
    CCLineColor: System.Drawing.Color  # static
    CurrentCalibrationSampleMarkerColor: System.Drawing.Color  # static
    CurrentSampleMarkerColor: System.Drawing.Color  # static
    CurveColor: System.Drawing.Color  # static
    DefaultAutoScaleToEnabledPoints: bool  # static # readonly
    DefaultBackColor: System.Drawing.Color  # static # readonly
    DefaultCCFillColor: System.Drawing.Color  # static # readonly
    DefaultCCLineColor: System.Drawing.Color  # static # readonly
    DefaultCurrentCalibrationSampleMarkerColor: (
        System.Drawing.Color
    )  # static # readonly
    DefaultCurrentSampleMarkerColor: System.Drawing.Color  # static # readonly
    DefaultCurveColor: System.Drawing.Color  # static # readonly
    DefaultForeColor: System.Drawing.Color  # static # readonly
    DefaultGridlinesColor: System.Drawing.Color  # static # readonly
    DefaultGridlinesVisible: bool  # static # readonly
    DefaultIstdResponsesColor: System.Drawing.Color  # static # readonly
    DefaultPointColor: System.Drawing.Color  # static # readonly
    DefaultPointSize: int  # static # readonly
    DefaultQCFillColor: System.Drawing.Color  # static # readonly
    DefaultQCLineColor: System.Drawing.Color  # static # readonly
    DefaultRelativeConcentration: bool  # static # readonly
    DefaultShowCC: bool  # static # readonly
    DefaultShowCurrentSampleMarker: bool  # static # readonly
    DefaultShowIstdResponses: bool  # static # readonly
    DefaultShowQC: bool  # static # readonly
    DefaultShowStandardDeviationBars: bool  # static # readonly
    DefaultStandardDeviationBarColor: System.Drawing.Color  # static # readonly
    DisabledPointColor: System.Drawing.Color  # static
    DisabledPointLineColor: System.Drawing.Color  # static
    FontSize: float  # static
    ForeColor: System.Drawing.Color  # static
    GridlinesColor: System.Drawing.Color  # static
    GridlinesVisible: bool  # static
    IstdResponsesColor: System.Drawing.Color  # static
    PaneBorderColor: System.Drawing.Color  # static
    PaneBorderWidth: int  # static
    PointColor: System.Drawing.Color  # static
    PointLineColor: System.Drawing.Color  # static
    PointSize: int  # static
    PrintLandscape: bool  # static
    PrintPageSettings: str  # static
    QCFillColor: System.Drawing.Color  # static
    QCLineColor: System.Drawing.Color  # static
    RelativeConcentration: bool  # static
    ShowCC: bool  # static
    ShowCoefficients: bool  # static
    ShowCurrentSampleMarker: bool  # static
    ShowIstdResponse: bool  # static
    ShowQC: bool  # static
    ShowStandardDeviationBars: bool  # static
    StandardDeviationBarColor: System.Drawing.Color  # static
    XLogScale: bool  # static
    YLogScale: bool  # static

    @staticmethod
    def CopyTo(configuration: System.Configuration.Configuration) -> None: ...
    @staticmethod
    def CopyFrom(configuration: System.Configuration.Configuration) -> None: ...
    @staticmethod
    def GetAvailableCurveFitTypes() -> List[CurveFitType]: ...
    @staticmethod
    def GetAvailableCurveFitWeightings() -> List[CurveFitWeighting]: ...
    @staticmethod
    def SetAssistantVisibleColumns(columns: List[str]) -> None: ...
    @staticmethod
    def GetAvailableCurveFitOrigins() -> List[CurveFitOrigin]: ...
    @staticmethod
    def GetAssistantVisibleColumns() -> List[str]: ...

class ChromSpecConfiguration:  # Class
    AbundanceLabelFormat: str  # static
    AlternatePeakFillColor: System.Drawing.Color  # static
    BackColor: System.Drawing.Color  # static
    ChromatogramLineWidth: int  # static
    DeconvolutedComponentColors: List[System.Drawing.Color]  # static
    DefaultAbundanceLabelFormat: str  # static # readonly
    DefaultAlternatePeakFillColor: System.Drawing.Color  # static # readonly
    DefaultBackColor: System.Drawing.Color  # static # readonly
    DefaultChromatogramLineWidth: int  # static # readonly
    DefaultDeconvolutedComponentColors: List[System.Drawing.Color]  # static # readonly
    DefaultFillAllQualifierPeaks: bool  # static # readonly
    DefaultFillOutofLimitQualifierPeaks: bool  # static # readonly
    DefaultFillPeaksTransparency: int  # static # readonly
    DefaultFillTargetPeaksInQualifiers: bool  # static # readonly
    DefaultForeColor: System.Drawing.Color  # static # readonly
    DefaultGridlinesColor: System.Drawing.Color  # static # readonly
    DefaultGridlinesVisible: bool  # static # readonly
    DefaultMIOutlierQualifierTitleColor: System.Drawing.Color  # static # readonly
    DefaultMaxColumnsPerPage: int  # static # readonly
    DefaultNoiseRegionsColor: System.Drawing.Color  # static # readonly
    DefaultNormalizeQualifiers: bool  # static # readonly
    DefaultNormalizeQuantifier: bool  # static # readonly
    DefaultOverrideSpectrum: bool  # static # readonly
    DefaultPrecursorColor: System.Drawing.Color  # static # readonly
    DefaultPrecursorFill: bool  # static # readonly
    DefaultPrecursorSize: int  # static # readonly
    DefaultPrimaryPeakAcceptedFillColor: System.Drawing.Color  # static # readonly
    DefaultPrimaryPeakInspectFillColor: System.Drawing.Color  # static # readonly
    DefaultPrimaryPeakManualIntegratedFillColor: (
        System.Drawing.Color
    )  # static # readonly
    DefaultPrimaryPeakRejectedFillColor: System.Drawing.Color  # static # readonly
    DefaultQualifierColors: List[System.Drawing.Color]  # static # readonly
    DefaultQualifierInfoLabelType: QualifierInfoLabelType  # static # readonly
    DefaultQualifiersTransparency: int  # static # readonly
    DefaultReferenceRetentionTimeColor: System.Drawing.Color  # static # readonly
    DefaultReferenceRetentionTimeDashStyle: (
        System.Drawing.Drawing2D.DashStyle
    )  # static # readonly
    DefaultReferenceWindowColor: System.Drawing.Color  # static # readonly
    DefaultReferenceWindowDashStyle: (
        System.Drawing.Drawing2D.DashStyle
    )  # static # readonly
    DefaultShowBaselineCalculationPoints: bool  # static # readonly
    DefaultShowBaselines: bool  # static # readonly
    DefaultShowChromatogramPeakLabelCaption: bool  # static # readonly
    DefaultShowChromatogramPeakLabelUnits: bool  # static # readonly
    DefaultShowComponentSpectrum: bool  # static # readonly
    DefaultShowDeconvolutedComponents: bool  # static # readonly
    DefaultShowDefaultChromTitle: bool  # static # readonly
    DefaultShowMassIndicators: bool  # static # readonly
    DefaultShowMatchScores: bool  # static # readonly
    DefaultShowNoiseRegions: bool  # static # readonly
    DefaultShowOriginalBaselines: bool  # static # readonly
    DefaultShowPatternSpectra: bool  # static # readonly
    DefaultShowQualifierAnnotations: bool  # static # readonly
    DefaultShowQualifierCoelutionScore: bool  # static # readonly
    DefaultShowReferenceLibrarySource: bool  # static # readonly
    DefaultShowReferenceRetentionTime: bool  # static # readonly
    DefaultShowReferenceSpectrum: bool  # static # readonly
    DefaultShowReferenceWindow: bool  # static # readonly
    DefaultShowTimeSegmentBorder: bool  # static # readonly
    DefaultShowUncertaintyBand: bool  # static # readonly
    DefaultSpectrumLineWidth: int  # static # readonly
    DefaultTimeSegmentBorderColor: System.Drawing.Color  # static # readonly
    DefaultUncertaintyBandDashStyle: (
        System.Drawing.Drawing2D.DashStyle
    )  # static # readonly
    DefaultWrapTitle: bool  # static # readonly
    FillAllQualifierPeaks: bool  # static
    FillOutofLimitQualifierPeaks: bool  # static
    FillPeaks: bool  # static
    FillPeaksTransparency: int  # static
    FillTargetPeaksInQualifiers: bool  # static
    FontSize: float  # static
    ForeColor: System.Drawing.Color  # static
    GridlinesColor: System.Drawing.Color  # static
    GridlinesVisible: bool  # static
    IstdOverlayAutoScaleType: ChromatogramAutoScaleType  # static
    IstdPeakAutoScaleType: ChromatogramAutoScaleType  # static
    IstdSpectrumAutoScaleType: ChromatogramAutoScaleType  # static
    MIOutlierQualifierTitleColor: System.Drawing.Color  # static
    MaxColumnsPerPage: int  # static
    NoiseRegionsColor: System.Drawing.Color  # static
    NormalizeQualifiers: bool  # static
    NormalizeQuantifier: bool  # static
    OriginalBaselineColor: System.Drawing.Color  # static
    OriginalBaselineWidth: float  # static
    OverlayAutoScaleType: ChromatogramAutoScaleType  # static
    Overlay_BackColor: System.Drawing.Color  # static
    Overlay_FontSize: float  # static
    Overlay_ForeColor: System.Drawing.Color  # static
    Overlay_GridlinesColor: System.Drawing.Color  # static
    Overlay_GridlinesVisible: bool  # static
    Overlay_ShowTimeSegmentBorder: bool  # static
    Overlay_TimeSegmentBorderColor: System.Drawing.Color  # static
    OverrideSpectrum: bool  # static
    PaneBorderColor: System.Drawing.Color  # static
    PaneBorderWidth: int  # static
    PlotColor: System.Drawing.Color  # static
    PrecursorColor: System.Drawing.Color  # static
    PrecursorFill: bool  # static
    PrecursorSize: int  # static
    PrimaryPeakAcceptedFillColor: System.Drawing.Color  # static
    PrimaryPeakInspectFillColor: System.Drawing.Color  # static
    PrimaryPeakManualIntegratedFillColor: System.Drawing.Color  # static
    PrimaryPeakRejectedFillColor: System.Drawing.Color  # static
    PrintLandscape: bool  # static
    PrintPageSettings: str  # static
    QualifierColors: List[System.Drawing.Color]  # static
    QualifierInfoLabelType: QualifierInfoLabelType  # static
    QualifiersTransparency: int  # static
    ReferenceRetentionTimeColor: System.Drawing.Color  # static
    ReferenceRetentionTimeDashStyle: System.Drawing.Drawing2D.DashStyle  # static
    ReferenceWindowColor: System.Drawing.Color  # static
    ReferenceWindowDashStyle: System.Drawing.Drawing2D.DashStyle  # static
    SelectedPaneBorderColor: System.Drawing.Color  # static
    ShowBaselineCalculationPoints: bool  # static
    ShowBaselines: bool  # static
    ShowChromatogram: bool  # static
    ShowChromatogramPeakLabelCaption: bool  # static
    ShowChromatogramPeakLabelUnits: bool  # static
    ShowComponentSpectrum: bool  # static
    ShowDeconvolutedComponents: bool  # static
    ShowDefaultChromTitle: bool  # static
    ShowIstd: bool  # static
    ShowManualIntegratoinHandles: bool  # static
    ShowMassIndicators: bool  # static
    ShowMatchScores: bool  # static
    ShowNoiseRegions: bool  # static
    ShowOriginalBaselines: bool  # static
    ShowPatternSpectra: bool  # static
    ShowPeakLabels: bool  # static
    ShowQualifierAnnotations: bool  # static
    ShowQualifierCoelutionScore: bool  # static
    ShowQualifiers: bool  # static
    ShowReferenceLibrarySource: bool  # static
    ShowReferenceRetentionTime: bool  # static
    ShowReferenceSpectrum: bool  # static
    ShowReferenceWindow: bool  # static
    ShowSpectrum: bool  # static
    ShowTimeSegmentBorder: bool  # static
    ShowUncertaintyBand: bool  # static
    SpectrumAutoScaleType: ChromatogramAutoScaleType  # static
    SpectrumLineWidth: int  # static
    Spectrum_BackColor: System.Drawing.Color  # static
    Spectrum_FontSize: float  # static
    Spectrum_ForeColor: System.Drawing.Color  # static
    Spectrum_GridlinesColor: System.Drawing.Color  # static
    Spectrum_GridlinesVisible: bool  # static
    TargetPeakAutoScaleType: ChromatogramAutoScaleType  # static
    TimeSegmentBorderColor: System.Drawing.Color  # static
    UncertaintyBandDashStyle: System.Drawing.Drawing2D.DashStyle  # static
    WrapTitle_Chromatogram: bool  # static
    WrapTitle_Overlay: bool  # static
    WrapTitle_Spectrum: bool  # static

    @staticmethod
    def CopyTo(config: System.Configuration.Configuration) -> None: ...
    @staticmethod
    def CopyFrom(config: System.Configuration.Configuration) -> None: ...
    @staticmethod
    def GetChromatogramPeakLabels() -> List[ChromatogramPeakLabelType]: ...
    @staticmethod
    def GetDefaultChromatogramPeakLabels() -> List[ChromatogramPeakLabelType]: ...
    @staticmethod
    def SetChromatogramPeakLabels(types: List[ChromatogramPeakLabelType]) -> None: ...
    @staticmethod
    def GetCaptionFromPeakLabelType(
        type: ChromatogramPeakLabelType, instrumentType: InstrumentType
    ) -> str: ...
    @staticmethod
    def SetChromTitleElements(elements: List[PlotTitleElement]) -> None: ...
    @staticmethod
    def GetChromTitleElements() -> List[PlotTitleElement]: ...
    @staticmethod
    def GetDefaultChromTitleElements() -> List[PlotTitleElement]: ...

class ChromatogramInformationConfiguration:  # Class
    AutoScaleAfter: float  # static
    BackColor: System.Drawing.Color  # static
    DefaultBackColor: System.Drawing.Color  # static # readonly
    DefaultForeColor: System.Drawing.Color  # static # readonly
    DefaultGridlinesColor: System.Drawing.Color  # static # readonly
    DefaultGridlinesVisible: bool  # static # readonly
    DefaultLinkXAxes: bool  # static # readonly
    DefaultLinkYAxes: bool  # static # readonly
    DefaultMaxNumRowsPerPage: int  # static # readonly
    DefaultPeakLabelsAllowOverlap: bool  # static # readonly
    DefaultPeakLabelsAnchorOnly: bool  # static # readonly
    DefaultPeakLabelsCaption: bool  # static # readonly
    DefaultPeakLabelsUnits: bool  # static # readonly
    DefaultPeakLabelsVertical: bool  # static # readonly
    ForeColor: System.Drawing.Color  # static
    GridlinesColor: System.Drawing.Color  # static
    GridlinesVisible: bool  # static
    HeadToTail: bool  # static
    LastCodec: str  # static
    LastExportFileName: str  # static
    LinkXAxes: bool  # static
    LinkYAxes: bool  # static
    MaxNumRowsPerPage: int  # static
    Overlay: bool  # static
    PaneBorderColor: System.Drawing.Color  # static
    PaneBorderWidth: int  # static # readonly
    PeakLabelsAllowOverlap: bool  # static
    PeakLabelsAnchorOnly: bool  # static
    PeakLabelsCaption: bool  # static
    PeakLabelsUnits: bool  # static
    PeakLabelsVertical: bool  # static
    PrintLandscape: bool  # static
    PrintPageSettings: str  # static
    SelectedPaneBorderColor: System.Drawing.Color  # static
    ShowDefaultTitle: bool  # static
    SynchronizeNavigation: bool  # static

    @staticmethod
    def GetTitleElements() -> List[PlotTitleElement]: ...
    @staticmethod
    def GetChromatogramPeakLabels() -> List[ChromatogramPeakLabelType]: ...
    @staticmethod
    def GetDefaultChromatogramPeakLabels() -> List[ChromatogramPeakLabelType]: ...
    @staticmethod
    def SetChromatogramPeakLabels(types: List[ChromatogramPeakLabelType]) -> None: ...
    @staticmethod
    def GetDefaultTitleElements() -> List[PlotTitleElement]: ...
    @staticmethod
    def SetTitleElements(elements: List[PlotTitleElement]) -> None: ...

class ColorScheme:  # Class
    def __init__(self) -> None: ...

    ColorSchemeChanged: System.EventHandler  # static

    DisplayName: str
    GraphicsColors: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.GraphicsColorScheme
    )
    GridColors: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.GridColorScheme
    )
    Name: str
    StyleFile: str

    def IsActive(self) -> bool: ...
    def ToString(self) -> str: ...
    def Activate(self) -> None: ...

class ColorSchemeSet:  # Class
    def __init__(self) -> None: ...

    ColorScheme: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.ColorScheme
    ]

    @staticmethod
    def Load() -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.ColorSchemeSet
    ): ...
    def GetColorScheme(
        self, name: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.ColorScheme
    ): ...
    def GetDefaultColorScheme(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.ColorScheme
    ): ...

class CompoundAtAGlanceConfiguration:  # Class
    BackColor: System.Drawing.Color  # static
    DefaultBackColor: System.Drawing.Color  # static # readonly
    DefaultForeColor: System.Drawing.Color  # static # readonly
    DefaultGridlinesColor: System.Drawing.Color  # static # readonly
    DefaultGridlinesVisible: bool  # static # readonly
    FontSize: float  # static
    ForeColor: System.Drawing.Color  # static
    GridlinesColor: System.Drawing.Color  # static
    GridlinesVisible: bool  # static
    PaneBorderColor: System.Drawing.Color  # static
    PrintLandscape: bool  # static
    PrintPageSettings: str  # static
    SelectedPaneBorderColor: System.Drawing.Color  # static

class DefaultColorScheme:  # Class
    def __init__(self) -> None: ...

    Application: str
    Instrument: str
    Name: str

class GraphicsColorScheme:  # Class
    def __init__(self) -> None: ...

    BackColor: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    ForeColor: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    PlotColor: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    QualifierColors: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    ]

    def IsActive(self) -> bool: ...
    def Activate(self) -> None: ...

class GridColorScheme:  # Class
    def __init__(self) -> None: ...

    ActiveCellBackColor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    ActiveCellBackColor2: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    ActiveCellForeColor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    ActiveCellForeColor2: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    ActiveCellHighlightBackColor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    ActiveCellHighlightBackColor2: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    ActiveCellHighlightForeColor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    ActiveCellHighlightForeColor2: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    BackColor: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    BorderColor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    CellBackColor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    CellForeColor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    DisplayName: str
    HeaderBackColor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    HeaderForeColor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    Name: str
    OutlierBackColorHigh: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    OutlierBackColorLow: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    OutlierForeColorHigh: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    OutlierForeColorLow: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    QuantErrorBackColor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )
    QuantErrorForeColor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.XmlColor
    )

    def IsActive(self) -> bool: ...
    def ToString(self) -> str: ...
    def Activate(self) -> None: ...

class GridConfiguration:  # Class
    ActiveCellBackColor: System.Drawing.Color  # static
    ActiveCellBackColor2: System.Drawing.Color  # static
    ActiveCellForeColor: System.Drawing.Color  # static
    ActiveCellForeColor2: System.Drawing.Color  # static
    ActiveCellHighlightBackColor: System.Drawing.Color  # static
    ActiveCellHighlightBackColor2: System.Drawing.Color  # static
    ActiveCellHighlightForeColor: System.Drawing.Color  # static
    ActiveCellHighlightForeColor2: System.Drawing.Color  # static
    BackColor: System.Drawing.Color  # static
    BorderColor: System.Drawing.Color  # static
    CellBackColor: System.Drawing.Color  # static
    CellForeColor: System.Drawing.Color  # static
    CellPadding: int  # static
    DefaultFontSize: float  # static
    DefaultFontSizePercent: float  # static # readonly
    FontSizePercent: float  # static
    HeaderBackColor: System.Drawing.Color  # static
    HeaderForeColor: System.Drawing.Color  # static
    HeaderStyle: str  # static
    HeaderWrapText: bool  # static # readonly

    @overload
    @staticmethod
    def GetColumnCaption(
        sectionName: str,
        relationName: str,
        columnName: str,
        instrumentType: InstrumentType,
    ) -> str: ...
    @overload
    @staticmethod
    def GetColumnCaption(
        sectionName: str,
        relationName: str,
        columnName: str,
        instrumentType: InstrumentType,
        culture: System.Globalization.CultureInfo,
    ) -> str: ...
    @staticmethod
    def SetAvailableSampleTypes(sampleTypes: List[str]) -> None: ...
    @staticmethod
    def SetColumnHidden(relationName: str, columnName: str, hidden: bool) -> None: ...
    @staticmethod
    def GetColumnAction(relationName: str, columnName: str) -> str: ...
    @staticmethod
    def GetTableCaption(sectionName: str, relationName: str) -> str: ...
    @staticmethod
    def GetVisibleColumns(
        sectionName: str,
        relationName: str,
        defaultVisibleColumns: bool,
        defaultValues: List[str],
    ) -> List[str]: ...
    @staticmethod
    def IsColumnHidden(
        relationName: str, columnName: str, instrumentType: InstrumentType
    ) -> bool: ...
    @staticmethod
    def GetColumnGroupCaption(relationName: str) -> str: ...
    @staticmethod
    def GetScanTypes(instrumentType: InstrumentType) -> List[ScanType]: ...
    @staticmethod
    def SetVisibleColumns(
        sectionName: str, relationName: str, columnNames: Iterable[str]
    ) -> None: ...
    @staticmethod
    def IsSampleTypeHidden(sampleType: str) -> bool: ...
    @staticmethod
    def GetColumnTooltipText(
        sectionName: str, relationName: str, columnName: str, instrument: InstrumentType
    ) -> str: ...
    @staticmethod
    def SetColumnCaption(
        sectionName: str,
        relationName: str,
        columnName: str,
        instrumentType: InstrumentType,
        value_: str,
    ) -> None: ...
    @staticmethod
    def GetCompoundListColumnGroupCaption(relationName: str) -> str: ...
    @staticmethod
    def GetAvailableSampleTypes() -> List[str]: ...
    @staticmethod
    def GetScanTypeCaption(
        instrumentType: InstrumentType, scanType: ScanType
    ) -> str: ...
    @staticmethod
    def SetSampleTypeCaption(sampleType: str, caption: str) -> None: ...
    @overload
    @staticmethod
    def GetSampleTypeCaption(sampleType: str, appType: str) -> str: ...
    @overload
    @staticmethod
    def GetSampleTypeCaption(
        sampleType: str, appType: str, culture: System.Globalization.CultureInfo
    ) -> str: ...

class MethodTableConfiguration:  # Class
    SectionName: str = ...  # static # readonly

    AllowColumnMoving: bool  # static
    ApplyMethodAnalyze: str  # static
    AssistantWidthRatio: float  # static
    AvailableSpecies: str  # static
    DisableAnalyzeBatch: bool  # static # readonly
    EnableHeaderClickSorting: bool  # static
    GenieIntegratorDefaultAreaReject: float  # static # readonly
    GenieIntegratorDefaultPeakWidth: float  # static # readonly
    GenieIntegratorDefaultShoulderDetection: bool  # static # readonly
    GenieIntegratorDefaultThreshold: float  # static # readonly
    GenieIntegratorDefaultUseDataScaleFactor: bool  # static # readonly
    GroupByTimeSegment: bool  # static
    MethodFromLibrary_CreateTargetsPerSpectrum: bool  # static
    MethodFromLibrary_NumQualifiers: int  # static
    MethodFromLibrary_RTCalibration: str  # static
    MethodFromLibrary_SumQualifiers: bool  # static
    MethodFromLibrary_TargetIonMode: str  # static
    MethodFromLibrary_UseRTCalibration: bool  # static
    ShowAssistantPane: bool  # static
    UsedSpecies: str  # static

    @staticmethod
    def GetColumnCaption(
        relationName: str, columnName: str, instrumentType: InstrumentType
    ) -> str: ...
    @staticmethod
    def GetMarkedColumns(
        tableName: str, task: MethodEditTaskMode, instrument: InstrumentType
    ) -> List[str]: ...
    @staticmethod
    def GetConcentrationUnits() -> List[str]: ...
    @staticmethod
    def SetSort(
        band: str, values: List[System.Collections.Generic.KeyValuePair[str, str]]
    ) -> None: ...
    @staticmethod
    def GetDefaultVisibleColumns(
        tableName: str,
        task: MethodEditTaskMode,
        instrument: InstrumentType,
        systemDefault: bool,
    ) -> List[str]: ...
    @staticmethod
    def GetTableVisible(
        tableName: str, task: MethodEditTaskMode, instrument: InstrumentType
    ) -> bool: ...
    @staticmethod
    def GetVisibleColumns(
        tableName: str,
        task: MethodEditTaskMode,
        outlier: Optional[OutlierColumns],
        instrument: InstrumentType,
        useSystemDefaultIfNotExist: bool,
    ) -> List[str]: ...
    @staticmethod
    def SetVisibleColumns(
        tableName: str,
        task: MethodEditTaskMode,
        outlier: Optional[OutlierColumns],
        instrument: InstrumentType,
        columns: List[str],
    ) -> None: ...
    @staticmethod
    def GetColumnTooltipText(
        relationName: str, columnName: str, instrument: InstrumentType
    ) -> str: ...
    @staticmethod
    def GetSort(
        band: str,
    ) -> List[System.Collections.Generic.KeyValuePair[str, str]]: ...
    @staticmethod
    def GetVisibleIntegrators() -> List[IntegratorType]: ...

class MetricsPlotConfiguration:  # Class
    BackColor: System.Drawing.Color  # static
    ForeColor: System.Drawing.Color  # static
    GridlinesColor: System.Drawing.Color  # static # readonly
    GridlinesVisible: bool  # static # readonly
    PaneBorderColor: System.Drawing.Color  # static
    PaneBorderWidth: int  # static
    PrintLandscape: bool  # static
    PrintPageSettings: str  # static

class NumberFormats(Agilent.MassHunter.Quantitative.UIModel.INumberFormats):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, defaultValues: bool) -> None: ...
    def InitCoreLibrary(self, instrumentType: InstrumentType) -> None: ...
    def GetColumns(self) -> List[str]: ...
    def SetColumnNumberFormat(
        self, instrumentType: InstrumentType, column: str, format: INumericCustomFormat
    ) -> None: ...
    def GetColumnNumberFormat(
        self, instrumentType: InstrumentType, column: str
    ) -> INumericCustomFormat: ...
    def Exists(self, instrument: InstrumentType, column: str) -> bool: ...
    def GetColumnCategory(self, column: str) -> str: ...
    def StoreFormats(self) -> None: ...

class ReportConfiguration:  # Class
    GenerateNow: bool  # static
    LastReportMethod: str  # static
    OpenReportFolder: bool  # static
    StartQueueViewer: bool  # static

class SampleDataConfiguration:  # Class
    AutoScaleAfter: float  # static
    BackColor: System.Drawing.Color  # static
    CompoundColors: List[System.Drawing.Color]  # static
    CompoundCurveColor: System.Drawing.Color  # static
    DeconvolutionComponentColors: List[System.Drawing.Color]  # static
    DefaultAutoScaleAfter: float  # static # readonly
    DefaultBackColor: System.Drawing.Color  # static # readonly
    DefaultCompoundColors: List[System.Drawing.Color]  # static # readonly
    DefaultCompoundCurveColor: System.Drawing.Color  # static # readonly
    DefaultDeconvolutionComponentColors: List[System.Drawing.Color]  # static # readonly
    DefaultForeColor: System.Drawing.Color  # static # readonly
    DefaultGridlinesColor: System.Drawing.Color  # static # readonly
    DefaultGridlinesVisible: bool  # static # readonly
    DefaultNormalize: bool  # static # readonly
    DefaultOverlayISTDCompounds: bool  # static # readonly
    DefaultOverlayTargetCompounds: bool  # static # readonly
    DefaultPeakLabelsAllowOverlap: bool  # static # readonly
    DefaultPeakLabelsVertical: bool  # static # readonly
    DefaultPrecursorColor: System.Drawing.Color  # static # readonly
    DefaultPrecursorFill: bool  # static # readonly
    DefaultPrecursorSize: int  # static # readonly
    DefaultShowChromatogramPeakLabelCaption: bool  # static # readonly
    DefaultShowChromatogramPeakLabelUnits: bool  # static # readonly
    DefaultShowSignalLabels: bool  # static # readonly
    DefaultShowTargetCompound: bool  # static # readonly
    DefaultShowTic: bool  # static # readonly
    DefaultShowTimeSegmentBorder: bool  # static # readonly
    DefaultSignalColors: List[System.Drawing.Color]  # static # readonly
    DefaultSpectrumColor: System.Drawing.Color  # static # readonly
    DefaultTargetPeakLabelsOnTIC: bool  # static # readonly
    DefaultTicColor: System.Drawing.Color  # static # readonly
    DefaultTimeSegmentBorderColor: System.Drawing.Color  # static # readonly
    FontSize: float  # static
    ForeColor: System.Drawing.Color  # static
    GridlinesColor: System.Drawing.Color  # static
    GridlinesVisible: bool  # static
    Normalize: bool  # static
    OverlayISTDCompounds: bool  # static
    OverlayTargetCompounds: bool  # static
    PaneBorderColor: System.Drawing.Color  # static
    PaneBorderWidth: int  # static
    PeakLabelsAllowOverlap: bool  # static
    PeakLabelsVertical: bool  # static
    PrecursorColor: System.Drawing.Color  # static
    PrecursorFill: bool  # static
    PrecursorSize: int  # static
    PrintLandscape: bool  # static
    PrintPageSettings: str  # static
    SelectedMassMarkerColor: System.Drawing.Color  # static
    SelectedPaneBorderColor: System.Drawing.Color  # static
    SelectedTimeRangeMarkerColor: System.Drawing.Color  # static
    ShowChromatogramPeakLabelCaption: bool  # static
    ShowChromatogramPeakLabelUnits: bool  # static
    ShowSignalLabels: bool  # static
    ShowTargetCompound: bool  # static
    ShowTic: bool  # static
    ShowTimeSegmentBorder: bool  # static
    SignalColors: List[System.Drawing.Color]  # static
    SpectrumColor: System.Drawing.Color  # static
    TargetPeakLabelsOnTIC: bool  # static
    TicColor: System.Drawing.Color  # static
    TimeSegmentBorderColor: System.Drawing.Color  # static

    @staticmethod
    def CopyTo(config: System.Configuration.Configuration) -> None: ...
    @staticmethod
    def CopyFrom(config: System.Configuration.Configuration) -> None: ...
    @staticmethod
    def GetDefaultOverlaySignals(instrumentType: InstrumentType) -> bool: ...
    @staticmethod
    def SetOverlayAllSignals(instrumentType: InstrumentType, value_: bool) -> None: ...
    @staticmethod
    def GetChromatogramPeakLabels() -> List[ChromatogramPeakLabelType]: ...
    @staticmethod
    def GetDefaultChromatogramPeakLabels() -> List[ChromatogramPeakLabelType]: ...
    @staticmethod
    def SetChromatogramPeakLabels(types: List[ChromatogramPeakLabelType]) -> None: ...
    @staticmethod
    def GetOverlayAllSignals(instrumentType: InstrumentType) -> bool: ...

class ScriptConfiguration:  # Class
    CommandLogFilePath: str  # static # readonly
    CommandLogLanguage: str  # static # readonly
    CommandLogSwitch: bool  # static # readonly
    ScriptFolder: str  # static # readonly

class UIConfiguration:  # Class
    GroupName: str = ...  # static # readonly

    AnalysisDynamicToolCommand: str  # static
    AppStyle: str  # static
    AvailableDateTimeFormats: List[str]  # static # readonly
    ColorScheme: str  # static
    CompoundSortType: str  # static
    DefaultColorScheme: str  # static # readonly
    DefaultFontSize: float  # static # readonly
    DefaultGraphicsPaneBorderColor: System.Drawing.Color  # static # readonly
    DefaultGraphicsSelectedPaneBorderColor: System.Drawing.Color  # static # readonly
    DefaultShowManualIntegratoinHandles: bool  # static # readonly
    DockAllowFlexDocking: bool  # static
    DockAllowFloating: bool  # static
    DockShowPinButton: bool  # static
    DockWindowStyle: str  # static # readonly
    ExportFileFilterIndex: int  # static
    ExportFileMode: GridExportMode  # static
    ExportFileOpenFile: bool  # static
    ExportGraphicsAllPanes: bool  # static
    ExportGraphicsFitToPage: bool  # static
    ExportGraphicsImageFormat: System.Drawing.Imaging.ImageFormat  # static
    ExportGraphicsLastFolder: str  # static
    ExportGraphicsPageHeight: float  # static
    ExportGraphicsPageWidth: float  # static
    ExportGraphicsScale: float  # static
    ExportGraphicsSizeUnits: str  # static
    GraphicsBackColor: System.Drawing.Color  # static
    GraphicsDefaultBackColor: System.Drawing.Color  # static # readonly
    GraphicsDefaultForeColor: System.Drawing.Color  # static # readonly
    GraphicsDefaultGridlinesColor: System.Drawing.Color  # static # readonly
    GraphicsDefaultGridlinesVisible: bool  # static # readonly
    GraphicsDefaultPlotColor: System.Drawing.Color  # static # readonly
    GraphicsDefaultShowTimeSegmentBorder: bool  # static # readonly
    GraphicsDefaultTimeSegmentBorderColor: System.Drawing.Color  # static # readonly
    GraphicsForeColor: System.Drawing.Color  # static
    GraphicsGridlinesColor: System.Drawing.Color  # static
    GraphicsGridlinesVisible: bool  # static
    GraphicsPaneBorderColor: System.Drawing.Color  # static
    GraphicsPaneBorderWidth: int  # static
    GraphicsPlotColor: System.Drawing.Color  # static
    GraphicsPrecursorFillColor: System.Drawing.Color  # static
    GraphicsPrecursorLineColor: System.Drawing.Color  # static
    GraphicsPrecursorSize: int  # static
    GraphicsSelectedPaneBorderColor: System.Drawing.Color  # static
    InitialScript: str  # static # readonly
    LastBatchFolder: str  # static
    LastEnableAuditTrail: bool  # static
    LastFileFolder: str  # static
    LastLibraryMethodPath: str  # static
    LastLibraryPath: str  # static
    LastMethodBatchFolder: str  # static
    LastMethodFolder: str  # static
    LastRTCalibrationFile: str  # static
    LastReportGraphicsSettingsFolder: str  # static
    LastReportTemplateFolder: str  # static
    LastSampleFolder: str  # static
    LockApplicationInterval: int  # static # readonly
    LockNumberFormats: bool  # static # readonly
    ManualIntegrationHandleTransparency: int  # static # readonly
    MaxFontSize: float  # static # readonly
    MinFontSize: float  # static # readonly
    NavigatorPaneStyle: str  # static # readonly
    NavigatorPaneViewStyle: str  # static # readonly
    NumberFormatFile: str  # static # readonly
    PrintMargins: List[float]  # static
    QualAppPath: str  # static
    ToolbarCustomize: bool  # static
    ToolbarStyle: str  # static
    UseSureMassLabels: bool  # static # readonly
    WindowPosition: System.Drawing.Rectangle  # static
    WindowState: System.Windows.Forms.FormWindowState  # static

    @staticmethod
    def SetUserEnumValue(
        group: str, section: str, settings: str, value_: System.Enum
    ) -> None: ...
    @staticmethod
    def CopyTo(
        groupName: str, sectionName: str, config: System.Configuration.Configuration
    ) -> None: ...
    @staticmethod
    def CopyFrom(
        groupName: str, sectionName: str, config: System.Configuration.Configuration
    ) -> None: ...
    @overload
    @staticmethod
    def SetUserValue(group: str, section: str, settings: str, value_: str) -> None: ...
    @overload
    @staticmethod
    def SetUserValue(group: str, section: str, setting: str, value_: bool) -> None: ...
    @overload
    @staticmethod
    def SetUserValue(group: str, section: str, setting: str, value_: int) -> None: ...
    @overload
    @staticmethod
    def SetUserValue(group: str, section: str, setting: str, value_: int) -> None: ...
    @overload
    @staticmethod
    def SetUserValue(
        group: str, section: str, setting: str, color: System.Drawing.Color
    ) -> None: ...
    @overload
    @staticmethod
    def SetUserValue(
        groupName: str, sectionName: str, settingName: str, value_: float
    ) -> None: ...
    @overload
    @staticmethod
    def SetUserValue(
        groupName: str, sectionName: str, settingName: str, value_: System.Guid
    ) -> None: ...
    @staticmethod
    def GetRecentReportMethods() -> List[str]: ...
    @staticmethod
    def AddRecentBatch(
        dataStorage: IDataStorage, batchPath: str, batchFile: str
    ) -> None: ...
    @staticmethod
    def RemoveRecentBatch(
        dataStorage: IDataStorage, folder: str, file: str
    ) -> None: ...
    @staticmethod
    def SetToolbarVisible(paneId: str, toolbarId: str, value_: bool) -> None: ...
    @staticmethod
    def GetRecentBatches() -> List[str]: ...
    @staticmethod
    def ClearRecentBatches() -> None: ...
    @staticmethod
    def GetUserEnumValue(
        group: str,
        section: str,
        settings: str,
        type: System.Type,
        defaultValue: System.Enum,
    ) -> System.Enum: ...
    @overload
    @staticmethod
    def GetUserValue(
        group: str, section: str, settings: str, defaultValue: str
    ) -> str: ...
    @overload
    @staticmethod
    def GetUserValue(
        group: str, section: str, setting: str, defaultValue: bool
    ) -> bool: ...
    @overload
    @staticmethod
    def GetUserValue(
        group: str, section: str, setting: str, defaultValue: int
    ) -> int: ...
    @overload
    @staticmethod
    def GetUserValue(
        group: str, section: str, setting: str, defaultValue: int
    ) -> int: ...
    @overload
    @staticmethod
    def GetUserValue(
        group: str, section: str, setting: str, defaultValue: System.Drawing.Color
    ) -> System.Drawing.Color: ...
    @overload
    @staticmethod
    def GetUserValue(
        groupName: str, sectionName: str, settingName: str, defaultValue: float
    ) -> float: ...
    @overload
    @staticmethod
    def GetUserValue(
        groupName: str, sectionName: str, settingName: str, defaultValue: System.Guid
    ) -> System.Guid: ...
    @staticmethod
    def ClearRecentReportMethods() -> None: ...
    @staticmethod
    def SetMaxRecentBatches(max: int) -> None: ...
    @staticmethod
    def AddRecentReportMethod(path: str) -> None: ...
    @staticmethod
    def GetLocalValue(
        group: str, section: str, setting: str, defaultValue: bool
    ) -> bool: ...
    @staticmethod
    def GetToolbarVisible(paneId: str, toolbarId: str, defaultValue: bool) -> bool: ...

class WorktableConfiguration(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.GridConfiguration
):  # Class
    def __init__(self) -> None: ...

    SectionName: str = ...  # static # readonly

    AllowColumnMoving: bool  # static
    AutoReviewInterval: int  # static
    DefaultOutlierBackColor: System.Drawing.Color  # static # readonly
    DefaultOutlierBackColorHigh: System.Drawing.Color  # static # readonly
    DefaultOutlierBackColorLow: System.Drawing.Color  # static # readonly
    DefaultOutlierForeColor: System.Drawing.Color  # static # readonly
    DefaultOutlierForeColorHigh: System.Drawing.Color  # static # readonly
    DefaultOutlierForeColorLow: System.Drawing.Color  # static # readonly
    DefaultSingleCompoundView: Optional[bool]  # static
    DefaultTableViewMode: str  # static
    EnableHeaderClickSorting: bool  # static
    FixSampleColumns: bool  # static
    GroupSeparatorWidth: int  # static
    OutlierBackColor: System.Drawing.Color  # static
    OutlierBackColorHigh: System.Drawing.Color  # static
    OutlierBackColorLow: System.Drawing.Color  # static
    OutlierForeColor: System.Drawing.Color  # static
    OutlierForeColorHigh: System.Drawing.Color  # static
    OutlierForeColorLow: System.Drawing.Color  # static
    QuantErrorBackColor: System.Drawing.Color  # static
    QuantErrorForeColor: System.Drawing.Color  # static
    ReSortMIColumn: bool  # static
    SingleCompoundView: bool  # static
    TableViewMode: str  # static

    @staticmethod
    def GetColumnCaption(
        relationName: str, columnName: str, instrumentType: InstrumentType
    ) -> str: ...
    @staticmethod
    def IsColumnEditable(relationName: str, columnName: str) -> bool: ...
    @staticmethod
    def SetOutlierEnabled(name: str, enabled: bool) -> None: ...
    @staticmethod
    def GetDefaultVisibleColumns(
        relationName: str,
        isCompoundList: bool,
        isFlatMode: bool,
        isSingleCompound: bool,
        defaultValues: List[str],
    ) -> List[str]: ...
    @staticmethod
    def GetVisibleColumns(
        relationName: str,
        isCompoundList: bool,
        isFlatMode: bool,
        isSingleCompound: bool,
        defaultValues: List[str],
    ) -> List[str]: ...
    @staticmethod
    def SetVisibleColumns(
        relationName: str,
        isCompoundList: bool,
        isFlatMode: bool,
        isSingleCompound: bool,
        columnNames: Iterable[str],
    ) -> None: ...
    @staticmethod
    def GetOutlierCategoryCaption(category: str) -> str: ...
    @staticmethod
    def ClearColumnCaptionCache() -> None: ...
    @staticmethod
    def GetColumnTooltipText(
        relationName: str, columnName: str, instrument: InstrumentType
    ) -> str: ...
    @staticmethod
    def GetOutlierEnabled(name: str) -> bool: ...
    @staticmethod
    def GetOutlierVisible(name: str) -> bool: ...
    @staticmethod
    def GetSystemDefaultVisibleColumns(
        relationName: str, isCompoundList: bool, isFlat: bool, isSingle: bool
    ) -> List[str]: ...
    @staticmethod
    def SetDefaultVisibleColumns(
        relationName: str,
        isCompoundList: bool,
        isFlatMode: bool,
        isSingleCompound: bool,
        columns: List[str],
    ) -> None: ...
    @staticmethod
    def SetOutlierVisible(name: str, value_: bool) -> None: ...
    @staticmethod
    def GetOutlierCaption(outlier: str, application: str) -> str: ...

class XmlColor:  # Struct
    def __init__(self, color: System.Drawing.Color) -> None: ...

    Color: System.Drawing.Color
    Default: str

    @staticmethod
    def ToColor(value_: str) -> System.Drawing.Color: ...
    def ToString(self) -> str: ...
    @staticmethod
    def FromColor(color: System.Drawing.Color) -> str: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import QDB

# Stubs for namespace: Agilent.MassSpectrometry.MSDChem

class AcqMSFile:  # Class
    def __init__(self, strFileName: str) -> None: ...
    def Open(self) -> None: ...
    def GetSIMGroups(
        self,
    ) -> Iterable[Agilent.MassSpectrometry.MSDChem.AcqMSFile.SIMTimeSegment]: ...

    # Nested Types

    class SIMIon:  # Class
        Dwell: int  # readonly
        Label: str  # readonly
        MZ: float  # readonly
        PlotThisIon: bool  # readonly

    class SIMTimeSegment:  # Class
        def __init__(self) -> None: ...

        EMVParameter: float  # readonly
        Group: int  # readonly
        GroupDwell: int  # readonly
        MassGain: float  # readonly
        MassOffset: float  # readonly
        Name: str  # readonly
        NoEICPlot: int  # static # readonly
        NumberOfIons: int  # readonly
        NumberOfSingleIonChromatograms: int  # readonly
        StartTime: float  # readonly
        UseTimeSegmentEMVParameter: bool  # readonly
        Wide: bool  # readonly

        def GetIons(
            self,
        ) -> Iterable[Agilent.MassSpectrometry.MSDChem.AcqMSFile.SIMIon]: ...

class CVTINFO:  # Class
    def __init__(self) -> None: ...

    DataDelta: float
    DataTime: float
    DataValue: int
    SigHdr_SigID: int
    SigHdr_nPts: int
    SigID: int

class ElementParse:  # Class
    def __init__(self) -> None: ...
    def LoadAWtable(self, tableFile: str) -> None: ...
    def CalcMw(self, formStr: str, mw: float) -> None: ...
    def ParseOneLevel(self, inputStr: str, strPos: int, succeeded: int) -> int: ...
    def TallyFormula(self, index: int, multiplier: int) -> None: ...

class ExtensionSpecificFolderBrowserDialog(System.IDisposable):  # Class
    def __init__(self) -> None: ...

    Description: str
    Extension: str
    SelectedPath: str
    ShowNewFolderButton: bool

    def Close(self) -> None: ...
    def Dispose(self) -> None: ...
    def ShowDialog(self) -> System.Windows.Forms.DialogResult: ...

class FileCheckStructU6890:  # Class
    def __init__(self) -> None: ...

    CheckSum: List[int]
    FILEEXTENSIONULEN: int = ...  # static # readonly
    FileExtensionUStr: str

class FileCheckStructU7890:  # Class
    def __init__(self) -> None: ...

    CheckSum: List[int]
    FILEEXTENSIONULEN: int = ...  # static # readonly
    FileExtensionUStr: str

class FullSequenceDownloadDataSet(
    System.IDisposable,
    System.ComponentModel.ISupportInitializeNotification,
    System.IServiceProvider,
    System.Data.DataSet,
    System.Xml.Serialization.IXmlSerializable,
    System.Runtime.Serialization.ISerializable,
    System.ComponentModel.IListSource,
    System.ComponentModel.ISupportInitialize,
    System.ComponentModel.IComponent,
):  # Class
    def __init__(self) -> None: ...

    Method: (
        Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodDataTable
    )  # readonly
    Relations: System.Data.DataRelationCollection  # readonly
    Sample: (
        Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleDataTable
    )  # readonly
    SchemaSerializationMode: System.Data.SchemaSerializationMode
    Sequence: (
        Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceDataTable
    )  # readonly
    Tables: System.Data.DataTableCollection  # readonly

    @staticmethod
    def GetTypedDataSetSchema(
        xs: System.Xml.Schema.XmlSchemaSet,
    ) -> System.Xml.Schema.XmlSchemaComplexType: ...
    def Clone(self) -> System.Data.DataSet: ...

    # Nested Types

    class MethodDataTable(
        System.ComponentModel.ISupportInitialize,
        Iterable[Any],
        System.ComponentModel.ISupportInitializeNotification,
        System.Xml.Serialization.IXmlSerializable,
        System.ComponentModel.IComponent,
        System.Data.TypedTableBase[
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRow
        ],
        System.Runtime.Serialization.ISerializable,
        Iterable[
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRow
        ],
        System.ComponentModel.IListSource,
        System.IDisposable,
        System.IServiceProvider,
    ):  # Class
        def __init__(self) -> None: ...

        Count: int  # readonly
        IDPathColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRow: ...
        MethodIDColumn: System.Data.DataColumn  # readonly

        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        def NewMethodRow(
            self,
        ) -> Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRow: ...
        def Clone(self) -> System.Data.DataTable: ...
        @overload
        def AddMethodRow(
            self,
            row: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRow,
        ) -> None: ...
        @overload
        def AddMethodRow(
            self,
            IDPath: str,
            parentSampleRowByFK_Sample_Method: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRow,
        ) -> Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRow: ...
        def RemoveMethodRow(
            self,
            row: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRow,
        ) -> None: ...

        MethodRowChanged: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRowChangeEventHandler
        )  # Event
        MethodRowChanging: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRowChangeEventHandler
        )  # Event
        MethodRowDeleted: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRowChangeEventHandler
        )  # Event
        MethodRowDeleting: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRowChangeEventHandler
        )  # Event

    class MethodRow(System.Data.DataRow):  # Class
        IDPath: str
        MethodID: int
        SampleRow: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRow
        )

        def SetIDPathNull(self) -> None: ...
        def SetMethodIDNull(self) -> None: ...
        def IsIDPathNull(self) -> bool: ...
        def IsMethodIDNull(self) -> bool: ...

    class MethodRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRow
        )  # readonly

    class MethodRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRowChangeEvent,
        ) -> None: ...

    class SampleDataTable(
        System.ComponentModel.ISupportInitialize,
        Iterable[Any],
        System.ComponentModel.ISupportInitializeNotification,
        System.Data.TypedTableBase[
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRow
        ],
        System.Xml.Serialization.IXmlSerializable,
        System.ComponentModel.IComponent,
        System.Runtime.Serialization.ISerializable,
        Iterable[
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRow
        ],
        System.ComponentModel.IListSource,
        System.IDisposable,
        System.IServiceProvider,
    ):  # Class
        def __init__(self) -> None: ...

        Count: int  # readonly
        ExpectedBarcodeFrontColumn: System.Data.DataColumn  # readonly
        ExpectedBarcodeRearColumn: System.Data.DataColumn  # readonly
        InjectionLocationColumn: System.Data.DataColumn  # readonly
        InjectionSourceColumn: System.Data.DataColumn  # readonly
        InjectionVialColumn: System.Data.DataColumn  # readonly
        InjectorVolumeColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRow: ...
        MethodAlreadyUsedCodeColumn: System.Data.DataColumn  # readonly
        MethodIDColumn: System.Data.DataColumn  # readonly
        SampleNameColumn: System.Data.DataColumn  # readonly
        SampleOfMethColumn: System.Data.DataColumn  # readonly
        SeqLineColumn: System.Data.DataColumn  # readonly
        TrayNameColumn: System.Data.DataColumn  # readonly
        UseHeadspaceColumn: System.Data.DataColumn  # readonly

        def FindBySeqLine(
            self, SeqLine: int
        ) -> Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRow: ...
        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        @overload
        def AddSampleRow(
            self,
            row: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRow,
        ) -> None: ...
        @overload
        def AddSampleRow(
            self,
            SampleOfMeth: int,
            SeqLine: int,
            InjectionVial: int,
            InjectionSource: int,
            MethodAlreadyUsedCode: int,
            UseHeadspace: str,
            MethodID: int,
            InjectionLocation: str,
            ExpectedBarcodeFront: str,
            ExpectedBarcodeRear: str,
            InjectorVolume: float,
            TrayName: str,
            SampleName: str,
        ) -> Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRow: ...
        def Clone(self) -> System.Data.DataTable: ...
        def NewSampleRow(
            self,
        ) -> Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRow: ...
        def RemoveSampleRow(
            self,
            row: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRow,
        ) -> None: ...

        SampleRowChanged: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRowChangeEventHandler
        )  # Event
        SampleRowChanging: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRowChangeEventHandler
        )  # Event
        SampleRowDeleted: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRowChangeEventHandler
        )  # Event
        SampleRowDeleting: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRowChangeEventHandler
        )  # Event

    class SampleRow(System.Data.DataRow):  # Class
        ExpectedBarcodeFront: str
        ExpectedBarcodeRear: str
        InjectionLocation: str
        InjectionSource: int
        InjectionVial: int
        InjectorVolume: float
        MethodAlreadyUsedCode: int
        MethodID: int
        SampleName: str
        SampleOfMeth: int
        SeqLine: int
        TrayName: str
        UseHeadspace: str

        def SetInjectionLocationNull(self) -> None: ...
        def IsInjectionSourceNull(self) -> bool: ...
        def SetUseHeadspaceNull(self) -> None: ...
        def SetInjectionSourceNull(self) -> None: ...
        def IsSampleOfMethNull(self) -> bool: ...
        def IsSampleNameNull(self) -> bool: ...
        def SetMethodAlreadyUsedCodeNull(self) -> None: ...
        def IsExpectedBarcodeFrontNull(self) -> bool: ...
        def SetExpectedBarcodeFrontNull(self) -> None: ...
        def SetTrayNameNull(self) -> None: ...
        def IsInjectorVolumeNull(self) -> bool: ...
        def IsExpectedBarcodeRearNull(self) -> bool: ...
        def SetInjectorVolumeNull(self) -> None: ...
        def SetInjectionVialNull(self) -> None: ...
        def IsTrayNameNull(self) -> bool: ...
        def SetExpectedBarcodeRearNull(self) -> None: ...
        def SetSampleNameNull(self) -> None: ...
        def GetMethodRows(
            self,
        ) -> List[
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.MethodRow
        ]: ...
        def IsUseHeadspaceNull(self) -> bool: ...
        def IsInjectionLocationNull(self) -> bool: ...
        def IsMethodAlreadyUsedCodeNull(self) -> bool: ...
        def IsInjectionVialNull(self) -> bool: ...
        def SetSampleOfMethNull(self) -> None: ...

    class SampleRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRow
        )  # readonly

    class SampleRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SampleRowChangeEvent,
        ) -> None: ...

    class SequenceDataTable(
        System.ComponentModel.ISupportInitialize,
        Iterable[
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRow
        ],
        Iterable[Any],
        System.ComponentModel.ISupportInitializeNotification,
        System.Xml.Serialization.IXmlSerializable,
        System.ComponentModel.IComponent,
        System.Data.TypedTableBase[
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRow
        ],
        System.Runtime.Serialization.ISerializable,
        System.ComponentModel.IListSource,
        System.IDisposable,
        System.IServiceProvider,
    ):  # Class
        def __init__(self) -> None: ...

        Count: int  # readonly
        IDPathColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRow
        ): ...
        MethodCountColumn: System.Data.DataColumn  # readonly
        SampleCountColumn: System.Data.DataColumn  # readonly

        @overload
        def AddSequenceRow(
            self,
            row: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRow,
        ) -> None: ...
        @overload
        def AddSequenceRow(
            self, IDPath: str, SampleCount: int, MethodCount: int
        ) -> (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRow
        ): ...
        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        def NewSequenceRow(
            self,
        ) -> (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRow
        ): ...
        def Clone(self) -> System.Data.DataTable: ...
        def RemoveSequenceRow(
            self,
            row: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRow,
        ) -> None: ...

        SequenceRowChanged: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRowChangeEventHandler
        )  # Event
        SequenceRowChanging: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRowChangeEventHandler
        )  # Event
        SequenceRowDeleted: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRowChangeEventHandler
        )  # Event
        SequenceRowDeleting: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRowChangeEventHandler
        )  # Event

    class SequenceRow(System.Data.DataRow):  # Class
        IDPath: str
        MethodCount: int
        SampleCount: int

        def IsIDPathNull(self) -> bool: ...
        def IsSampleCountNull(self) -> bool: ...
        def IsMethodCountNull(self) -> bool: ...
        def SetSampleCountNull(self) -> None: ...
        def SetIDPathNull(self) -> None: ...
        def SetMethodCountNull(self) -> None: ...

    class SequenceRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRow
        )  # readonly

    class SequenceRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.MSDChem.FullSequenceDownloadDataSet.SequenceRowChangeEvent,
        ) -> None: ...

class GC5890DataFile(Agilent.MassSpectrometry.MSDChem.IChemStationDataFile):  # Class
    def __init__(self, i32FileSubType: int) -> None: ...

    END_FLAG: int = ...  # static # readonly

    ActualBarcode: str  # readonly
    DateTime: str  # readonly
    InstrumentName: str  # readonly
    def __getitem__(self, iTimeOrAbundance: int, jPointNumber: int) -> float: ...
    MethodFile: str  # readonly
    Operator: str  # readonly
    SampleName: str  # readonly

    def GetYArray(self) -> List[float]: ...
    def OpenRead(self, filename: str) -> bool: ...

class GC6890DataFile(Agilent.MassSpectrometry.MSDChem.IChemStationDataFile):  # Class
    def __init__(self) -> None: ...

    ActualBarcode: str  # readonly
    DateTime: str  # readonly
    InstrumentName: str  # readonly
    def __getitem__(self, iTimeOrAbundance: int, jPointNumber: int) -> float: ...
    MethodFile: str  # readonly
    Operator: str  # readonly
    SampleName: str  # readonly

    def GetNumPoints(self) -> int: ...
    def GetYArray(self) -> List[float]: ...
    def OpenRead(self, filename: str) -> bool: ...

class GC7890DataFile(Agilent.MassSpectrometry.MSDChem.IChemStationDataFile):  # Class
    def __init__(self) -> None: ...

    ActualBarcode: str  # readonly
    DateTime: str  # readonly
    InstrumentName: str  # readonly
    def __getitem__(self, iTimeOrAbundance: int, jPointNumber: int) -> float: ...
    MethodFile: str  # readonly
    Operator: str  # readonly
    SampleName: str  # readonly

    def GetYArray(self) -> List[float]: ...
    def OpenRead(self, filename: str) -> bool: ...

class IChemStationDataFile(object):  # Interface
    InstrumentName: str  # readonly

class IILDCommand(object):  # Interface
    def DoSomething(self) -> None: ...

class InstConfigItem(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    IC_ALS_ID: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_ALS_TYPE: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_APPLICATION: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_AUXINLET_ENABLED: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_AVAILABLE_SOURCES: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_DETECTOR_IRIS: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_GC_ID: Agilent.MassSpectrometry.MSDChem.InstConfigItem = ...  # static # readonly
    IC_GC_NETWORK_ADDRESS: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_GC_STATUS_PANEL_STATE: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_GC_TOWER: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_HS_IP: Agilent.MassSpectrometry.MSDChem.InstConfigItem = ...  # static # readonly
    IC_HS_PORT: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_HS_TYPE: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_INJECTOR_STATUS_PANEL_STATE: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_INLET_GC: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_INSTR_OFFLINE: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_IR_ID: Agilent.MassSpectrometry.MSDChem.InstConfigItem = ...  # static # readonly
    IC_IR_TYPE: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_MAX_ITEM_ID: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_MAX_MS_OPTION_ID: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_MS_CI: Agilent.MassSpectrometry.MSDChem.InstConfigItem = ...  # static # readonly
    IC_MS_CI_OFFSET: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_MS_CONNECTION: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_MS_DCPOL: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_MS_EI: Agilent.MassSpectrometry.MSDChem.InstConfigItem = ...  # static # readonly
    IC_MS_EI_OFFSET: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_MS_ID: Agilent.MassSpectrometry.MSDChem.InstConfigItem = ...  # static # readonly
    IC_MS_LCINST: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_MS_NETWORK_ADDRESS: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_MS_OPTIONS_START: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_MS_TYPE: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly
    IC_PALALS_IP: Agilent.MassSpectrometry.MSDChem.InstConfigItem = (
        ...
    )  # static # readonly

class MAT_REGRESSION:  # Class
    def __init__(self) -> None: ...

    A: System.Array[float]
    FLT_MIN: float = ...  # static # readonly
    MAX_ORDER: int = ...  # static # readonly
    coeff: List[float]
    residual: float

    def HigherOrderRegression(
        self, x: List[float], y: List[float], numPoints: int, wParam: int
    ) -> bool: ...

class MSDChemDataMSFile(Agilent.MassSpectrometry.MSDChem.IChemStationDataFile):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, bUseExtendedHeader: bool) -> None: ...

    ALSBottle: str
    AcqDateTime: System.DateTime
    AcquisitionMethod: str
    ActualBarcode: str
    BasePeakOffset: int
    ComputerName: str
    DataName: str
    ExpectedBarcode: str
    FileFullPathName: str  # readonly
    FileName: str  # readonly
    FilePath: str  # readonly
    HashExtra1: str
    HashExtra2: str
    HashForAcquisition: str
    HashForTune: str
    Inlet: str
    InstName: str
    InstrumentName: str  # readonly
    LanguageID: int
    MaximumRetentionTime: float
    MaximumSignal: int
    MinimumRetentionTime: float
    MinimumSignal: int
    MiscInfo: str
    NumberOfSpectra: int
    Operator: str
    Replicate: int
    SequenceIndex: int
    SpectralRecordsOffset: int  # readonly
    TimeZone: int
    UserAccountName: str
    UserName: str
    UsesExtendedHeaderFormat: bool  # readonly

    def InitRecover(self) -> None: ...
    def OpenRead(self, filename: str) -> bool: ...
    def GetSpectrumDataTypeByIndex1Based(
        self, iSpectrumNumber1Based: int
    ) -> Agilent.MassSpectrometry.MSDChem.SpectralRecordType: ...
    @staticmethod
    def PackAbundance(unpacked: int) -> int: ...
    def SetDataFilePath(self, dataFilePath: str, dataFileName: str) -> None: ...
    def GetExtendedHeaderTime(self) -> System.DateTime: ...
    def GetDirectoryRecord1Based(
        self,
        iIndexOneBased: int,
        iDataOffsetInBytesZeroBased: int,
        dRetentionTimeMinutes: float,
        iTotalResponse: int,
    ) -> None: ...
    @overload
    def AppendSpectrum(
        self, mz: List[float], intensity: List[float], retentionTimeMinutes: float
    ) -> None: ...
    @overload
    def AppendSpectrum(
        self,
        mz: List[float],
        intensity: List[float],
        retentionTimeMinutes: float,
        specType: Agilent.MassSpectrometry.MSDChem.SpectralRecordType,
        status: int,
    ) -> None: ...
    @overload
    def AppendSpectrum(
        self, mz: List[float], intensity: List[float], retentionTimeMinutes: float
    ) -> None: ...
    @overload
    def AppendSpectrum(
        self, smartCardDataBuffer: List[int], i32NumberOfBytesToWrite: int
    ) -> None: ...
    @overload
    def AppendSpectrum(
        self,
        mz: List[float],
        intensity: List[float],
        retentionTimeMinutes: float,
        specType: Agilent.MassSpectrometry.MSDChem.SpectralRecordType,
        status: int,
    ) -> None: ...
    def RecoverSpectrumByIndex1Based(
        self, iSpectrumNumber1Based: int, dRetentionTimeMinutes: float
    ) -> List[float]: ...
    @staticmethod
    def HasStatusIndicator(
        u16Status: int,
        code: Agilent.MassSpectrometry.MSDChem.MSDChemDataMSFile.SpectralStatusCodes,
    ) -> bool: ...
    @overload
    def Close(self) -> None: ...
    @overload
    def Close(self, updateHeader: bool) -> None: ...
    def GetStandardHeaderTime(self) -> str: ...
    @overload
    def GetSpectrumByIndex1Based(
        self,
        iSpectrumNumber1Based: int,
        dRetentionTime: float,
        u16Status: int,
        u16DataType: int,
    ) -> List[float]: ...
    @overload
    def GetSpectrumByIndex1Based(
        self,
        iSpectrumNumber1Based: int,
        dRetentionTime: float,
        u16Status: int,
        dMZs: List[float],
        dIntensities: List[float],
    ) -> None: ...
    @overload
    def GetSpectrumByIndex1Based(
        self, iSpectrumNumber1Based: int, dRetentionTime: float
    ) -> List[float]: ...
    @overload
    def GetSpectrumByIndex1Based(
        self, iSpectrumNumber1Based: int, dRetentionTime: float, u16DataType: int
    ) -> List[float]: ...
    def GetTotalIonByTime(
        self,
        dTimeRangeLowMin: float,
        dTimeRangeHighMin: float,
        times: System.Collections.Generic.List[float],
        intensities: System.Collections.Generic.List[float],
    ) -> None: ...
    @staticmethod
    def GetSpectrumFromSmartcardBuffer(
        smartCardDataBuffer: List[int],
        dRetentionTimeMinutes: float,
        dMZs: List[float],
        dIntensities: List[float],
        dMinX: float,
        dMaxX: float,
        dMaxY: float,
        dBasePeakMZ: float,
        dBasePeakIntensity: float,
        dTIC: float,
        spectralRecordType: Agilent.MassSpectrometry.MSDChem.SpectralRecordType,
    ) -> None: ...
    @overload
    def OpenWrite(self, filename: str) -> bool: ...
    @overload
    def OpenWrite(
        self,
        newFileName: str,
        guideFile: Agilent.MassSpectrometry.MSDChem.MSDChemDataMSFile,
    ) -> bool: ...
    def SetMethodPath(self, methodPath: str, methodFileName: str) -> None: ...
    def Snapshot(self, snapshotFileName: str) -> None: ...
    def SetTuneFilePath(self, tuneFilePath: str, tuneFileName: str) -> None: ...

    # Nested Types

    class SpectralStatusCodes(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        STATUS_MS_FAULT: (
            Agilent.MassSpectrometry.MSDChem.MSDChemDataMSFile.SpectralStatusCodes
        ) = ...  # static # readonly
        STATUS_MS_IOERROR: (
            Agilent.MassSpectrometry.MSDChem.MSDChemDataMSFile.SpectralStatusCodes
        ) = ...  # static # readonly
        STATUS_OK: (
            Agilent.MassSpectrometry.MSDChem.MSDChemDataMSFile.SpectralStatusCodes
        ) = ...  # static # readonly
        STATUS_RECORD_OVERFLOW: (
            Agilent.MassSpectrometry.MSDChem.MSDChemDataMSFile.SpectralStatusCodes
        ) = ...  # static # readonly
        STATUS_TIC_OVERFLOW: (
            Agilent.MassSpectrometry.MSDChem.MSDChemDataMSFile.SpectralStatusCodes
        ) = ...  # static # readonly
        STATUS_VALUE_OVERFLOW: (
            Agilent.MassSpectrometry.MSDChem.MSDChemDataMSFile.SpectralStatusCodes
        ) = ...  # static # readonly

class MSDChemUtil:  # Class
    def __init__(self) -> None: ...

    GROUP_ACQ_ANALYSTS_I: str = ...  # static # readonly
    GROUP_ACQ_ANALYSTS_II: str = ...  # static # readonly
    GROUP_ACQ_ANALYSTS_III: str = ...  # static # readonly
    GROUP_ACQ_MANAGERS: str = ...  # static # readonly

    @staticmethod
    def FindRealRoots(
        coeff: List[float], root: List[float], order: int, nRootsFound: int
    ) -> None: ...
    @staticmethod
    def RoleSecurityMode() -> bool: ...
    @staticmethod
    def lsplitspec(fullspec: str, KeepSlash: bool, lastchunk: str) -> None: ...
    @staticmethod
    def AreRealsEqual(x: float, y: float) -> bool: ...
    @staticmethod
    def RemoveAnalystUsersAndGroups(
        messages: System.Collections.Generic.List[str],
    ) -> bool: ...
    @staticmethod
    def FloatToString(dValue: float, nPrecision: int, psString: str) -> None: ...
    @staticmethod
    def lfullspec(fullspec: str, DefPath: str) -> str: ...
    @staticmethod
    def ReadCStringW(br: System.IO.BinaryReader) -> str: ...
    @staticmethod
    def WritePrivateProfileString(
        lpApplicationName: str, lpKeyName: str, lpString: str, lpFileName: str
    ) -> int: ...
    @staticmethod
    def SeparateInput(
        inputLine: str, runstringParam: System.Collections.Generic.List[str]
    ) -> None: ...
    @staticmethod
    def PrintTextFile(
        strFileName: str,
        i32NumberOfPagesPrinted: int,
        font: System.Drawing.Font,
        bUseSoftMargin: bool,
    ) -> None: ...
    @staticmethod
    def RegisterDistillerSettings(
        pathName: str, exeName: str, outfileName: str
    ) -> None: ...
    @staticmethod
    def GetExecutablesPath() -> str: ...
    @staticmethod
    def IsHeadspaceDriverInstalled() -> bool: ...
    @staticmethod
    def FormDispose(form: System.Windows.Forms.Form) -> None: ...
    @staticmethod
    def GetUTCOffsetString(dateTime: System.DateTime) -> str: ...
    @overload
    @staticmethod
    def GetPrivateProfileString(
        lpAppName: str,
        lpKeyName: str,
        lpDefault: str,
        lpReturnedString: System.Text.StringBuilder,
        nSize: int,
        lpFileName: str,
    ) -> int: ...
    @overload
    @staticmethod
    def GetPrivateProfileString(
        lpAppName: str,
        lpKeyName: str,
        lpDefault: str,
        lpReturnedString: List[str],
        nSize: int,
        lpFileName: str,
    ) -> int: ...
    @staticmethod
    def LocalePreferredFontFaceName(
        fontUsageCategory: Agilent.MassSpectrometry.MSDChem.MSDChemUtil.FontUsageCategory,
    ) -> str: ...
    @staticmethod
    def roundToInt(x: float) -> int: ...
    @staticmethod
    def roundToLong(x: float) -> int: ...
    @staticmethod
    def CreateApplicationFileName(
        rstrFileName: str, bOverwrite: bool, rstrRootElementName: str
    ) -> Agilent.MassSpectrometry.MSDChem.XMLConfiguration: ...
    @staticmethod
    def IsLeanMeanDataAnalysisInstalled() -> bool: ...
    @staticmethod
    def SetApplicationFileName(
        rstrFileName: str,
    ) -> Agilent.MassSpectrometry.MSDChem.XMLConfiguration: ...
    @staticmethod
    def IsExtOk(filename: str, extension: str, ForceAppend: bool) -> bool: ...
    @overload
    @staticmethod
    def UserPossessesRole(
        principalUser: System.Security.Principal.IPrincipal, role: str
    ) -> bool: ...
    @overload
    @staticmethod
    def UserPossessesRole(role: str) -> bool: ...
    @staticmethod
    def SetBusyCursor(formParent: System.Windows.Forms.Form, bWait: bool) -> None: ...
    @staticmethod
    def ChangeMultiExtension(filePathName: str, newExtension: str) -> None: ...
    @staticmethod
    def ChromatographFileType(strFileName: str) -> int: ...
    @staticmethod
    def GetInstallPath() -> str: ...
    @staticmethod
    def iscfr() -> bool: ...
    @overload
    @staticmethod
    def GetPageSizeInCharacters(
        font: System.Drawing.Font,
        columnsSize: int,
        rowsSize: int,
        nWidth: int,
        nHeight: int,
        dPaperSizeWidthInches: float,
        dPaperSizeHeightInches: float,
    ) -> None: ...
    @overload
    @staticmethod
    def GetPageSizeInCharacters(
        columnsSize: int, rowsSize: int, nWidth: int, nHeight: int
    ) -> None: ...
    @staticmethod
    def CopyDirectory(sourceFolder: str, destinationLocation: str) -> None: ...
    @staticmethod
    def GetWindowDoc(strWindowInfoPath: str) -> System.Xml.XmlDocument: ...
    @staticmethod
    def AddAnalystUsersAndGroups(
        messages: System.Collections.Generic.List[str], addUsers: bool
    ) -> bool: ...
    @staticmethod
    def GetPrivateProfileInt(
        lpAppName: str, lpKeyName: str, lpDefault: int, lpFileName: str
    ) -> int: ...
    @staticmethod
    def KillProcesses(blarg: str, transcript: str) -> None: ...
    @staticmethod
    def EncryptPassword(strEncryptionKey: str, password: str) -> str: ...
    @staticmethod
    def FindMdiClient(
        parent: System.Windows.Forms.Form,
    ) -> System.Windows.Forms.MdiClient: ...
    @staticmethod
    def BlockInput(fBlockIt: bool) -> bool: ...
    @staticmethod
    def IsMsinsctlNet() -> bool: ...
    def IS_AddAnalystUsersAndGroups(self, addUsers: bool) -> bool: ...
    @staticmethod
    def GetGCFileDescClassName(filename: str) -> str: ...
    @staticmethod
    def cfroperator() -> str: ...
    @staticmethod
    def GetMemoryUsage(
        hProcess: System.IntPtr,
        pi32NumPageFaults: int,
        pi64WorkingSetSize: int,
        pi64PeakWorkingSetSize: int,
        pi64Private: int,
        piSystemPerfStats: List[int],
        iCountSystemPerfStats: int,
    ) -> None: ...
    @staticmethod
    def GetDateStampWithUTCOffset(dateTime: System.DateTime) -> str: ...

    # Nested Types

    class FontUsageCategory(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        Printing: Agilent.MassSpectrometry.MSDChem.MSDChemUtil.FontUsageCategory = (
            ...
        )  # static # readonly
        Screen: Agilent.MassSpectrometry.MSDChem.MSDChemUtil.FontUsageCategory = (
            ...
        )  # static # readonly
        ScreenFixedPitch: (
            Agilent.MassSpectrometry.MSDChem.MSDChemUtil.FontUsageCategory
        ) = ...  # static # readonly
        Unknown: Agilent.MassSpectrometry.MSDChem.MSDChemUtil.FontUsageCategory = (
            ...
        )  # static # readonly

    class Point:  # Struct
        x: int
        y: int

    class RECT:  # Struct
        bottom: int
        left: int
        right: int
        top: int

class Method:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def GetAcqMSItem(
        rstrMethodLocator: str, acqMSPathComponents: List[str], rstrResult: str
    ) -> bool: ...
    @overload
    @staticmethod
    def SetAcqCtlItem(
        rstrMethodLocator: str, acqCtlPathComponents: List[str], rstrValue: str
    ) -> bool: ...
    @overload
    @staticmethod
    def SetAcqCtlItem(
        rstrMethodLocator: str, acqCtlPathComponents: List[str], i32Value: int
    ) -> bool: ...
    @staticmethod
    def MSDChemGetMethodInteger(
        rstrMethodLocator: str, rstrItemLocator: str, pi32Result: int
    ) -> bool: ...
    @staticmethod
    def GetString(
        rstrMethodLocator: str, rstrItemLocator: str, rstrResult: str
    ) -> bool: ...
    @staticmethod
    def MSDChemGetMethodScalar(
        rstrMethodLocator: str, rstrItemLocator: str, pdResult: float
    ) -> bool: ...
    @staticmethod
    def GetAcqCtlItem(
        rstrMethodLocator: str, acqCtlPathComponents: List[str], rstrResult: str
    ) -> bool: ...

class PrintTextFileDocument(
    System.IDisposable,
    System.ComponentModel.IComponent,
    System.Drawing.Printing.PrintDocument,
):  # Class
    ...

class RC_OPERATION(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    RUNOP_ARM: Agilent.MassSpectrometry.MSDChem.RC_OPERATION = ...  # static # readonly
    RUNOP_FINALPRERUN: Agilent.MassSpectrometry.MSDChem.RC_OPERATION = (
        ...
    )  # static # readonly
    RUNOP_INITIALPRERUN: Agilent.MassSpectrometry.MSDChem.RC_OPERATION = (
        ...
    )  # static # readonly
    RUNOP_NULL: Agilent.MassSpectrometry.MSDChem.RC_OPERATION = ...  # static # readonly
    RUNOP_POSTRUN: Agilent.MassSpectrometry.MSDChem.RC_OPERATION = (
        ...
    )  # static # readonly
    RUNOP_PRERUN: Agilent.MassSpectrometry.MSDChem.RC_OPERATION = (
        ...
    )  # static # readonly
    RUNOP_SAMPLEPREP: Agilent.MassSpectrometry.MSDChem.RC_OPERATION = (
        ...
    )  # static # readonly

class ReportViewerCleaner(System.IDisposable):  # Class
    def __init__(self) -> None: ...
    def CollectHandlers(self) -> None: ...
    def CleanHandlers(self) -> None: ...
    def Dispose(self) -> None: ...

class STEConfigUtil:  # Class
    @staticmethod
    def WriteKeywords(configFile: str, value_: str) -> None: ...

class SignalHeader6890U:  # Class
    def __init__(self) -> None: ...

    HeaderSize: int
    HeaderVersion: int
    m_check: List[Agilent.MassSpectrometry.MSDChem.FileCheckStructU6890]
    m_signal: List[Agilent.MassSpectrometry.MSDChem.SignalInfoStruct6890]
    m_signalU: Agilent.MassSpectrometry.MSDChem.SignalScaleStructU6890

class SignalHeader7890U:  # Class
    def __init__(self) -> None: ...

    HeaderSize: int
    HeaderVersion: int
    m_check: List[Agilent.MassSpectrometry.MSDChem.FileCheckStructU7890]
    m_signal: List[Agilent.MassSpectrometry.MSDChem.SignalInfoStruct7890]
    m_signalU: Agilent.MassSpectrometry.MSDChem.SignalScaleStructU7890

class SignalInfoStruct5890:  # Class
    def __init__(self) -> None: ...

    BunchPower: int
    Detector: int
    Max: int
    Method: int
    Min: int
    PeakWidth: float
    Present: int
    Version: int
    WordAlign: int
    Zero: int

class SignalInfoStruct6890:  # Class
    def __init__(self) -> None: ...

    BunchPower: int
    Detector: int
    Max: int
    Method: int
    Min: int
    PeakWidth: float
    Present: int
    Version: int
    WordAlign: int
    Zero: float

class SignalInfoStruct7890:  # Class
    def __init__(self) -> None: ...

    BunchPower: int
    Detector: int
    Max: int
    Method: int
    Min: int
    PeakWidth: float
    Present: int
    Version: int
    WordAlign: int
    Zero: int

class SignalScaleStructU6890:  # Class
    def __init__(self) -> None: ...

    Intercept: float
    SIGDESCULEN: int = ...  # static # readonly
    SigDescrUStr: str
    Slope: float
    UNITSULEN: int = ...  # static # readonly
    UnitsUStr: str

class SignalScaleStructU7890:  # Class
    def __init__(self) -> None: ...

    Intercept: float
    SIGDESCULEN: int = ...  # static # readonly
    SigDescrUStr: str
    Slope: float
    UNITSULEN: int = ...  # static # readonly
    UnitsUStr: str

class SpectralRecordType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Capture: Agilent.MassSpectrometry.MSDChem.SpectralRecordType = (
        ...
    )  # static # readonly
    NormalScanSpectrum: Agilent.MassSpectrometry.MSDChem.SpectralRecordType = (
        ...
    )  # static # readonly
    ProfileScanSpectrum: Agilent.MassSpectrometry.MSDChem.SpectralRecordType = (
        ...
    )  # static # readonly
    Rawscan: Agilent.MassSpectrometry.MSDChem.SpectralRecordType = (
        ...
    )  # static # readonly
    SIMPlusScan_SIM: Agilent.MassSpectrometry.MSDChem.SpectralRecordType = (
        ...
    )  # static # readonly
    SIMPlusScan_Scan: Agilent.MassSpectrometry.MSDChem.SpectralRecordType = (
        ...
    )  # static # readonly
    SIMspectrum: Agilent.MassSpectrometry.MSDChem.SpectralRecordType = (
        ...
    )  # static # readonly
    SimRamp: Agilent.MassSpectrometry.MSDChem.SpectralRecordType = (
        ...
    )  # static # readonly
    TotalIon: Agilent.MassSpectrometry.MSDChem.SpectralRecordType = (
        ...
    )  # static # readonly

class UnsignedFloatEdit(
    System.IDisposable,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISynchronizeInvoke,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.TextBox,
):  # Class
    def __init__(self) -> None: ...
    def SetLegalRange(self, dLow: float, dHigh: float) -> None: ...
    def SetNumberOfDecimalPlaces(self, nDecimal: int) -> None: ...

class VersionInfo:  # Class
    def __init__(self, App: str, Product: str) -> None: ...

    App: str
    BuildDate: str
    BuildNumber: str
    Copyright: str
    Product: str
    Release: str
    Version: str

    def BuildVersionString(self, exePath: str) -> None: ...

class WindowInfo:  # Class
    @overload
    def __init__(
        self, name: str, x: int, y: int, w: int, h: int, show: bool
    ) -> None: ...
    @overload
    def __init__(
        self,
        name: str,
        location: System.Drawing.Point,
        size: System.Drawing.Size,
        show: bool,
    ) -> None: ...

    Height: int
    Location: System.Drawing.Point
    Name: str
    Size: System.Drawing.Size
    Visible: bool
    Width: int
    X: int
    Y: int

    def SetWindowInfo(self, strWindowInfoPath: str) -> None: ...
    def GetWindowInfo(self, strWindowInfoPath: str) -> None: ...

class XMLConfiguration:  # Class
    def SetConfiguredColor(
        self, instId: int, rstrValueName: str, dwRGB: int
    ) -> bool: ...
    def SetApplicationDWORD(
        self, rstrParentElementPath: str, rstrDWORDValueName: str, dwValue: int
    ) -> bool: ...
    def SetApplicationString(
        self, rstrParentElementPath: str, rstrStringValueName: str, rstrValue: str
    ) -> bool: ...
    def GetConfiguredColor(
        self, instId: int, rstrValueName: str, pdwRGB: int
    ) -> bool: ...
    def GetApplicationString(
        self,
        rstrParentElementPath: str,
        iParentPathOccurrenceIndex: int,
        rstrStringValueName: str,
        rstrValue: str,
    ) -> bool: ...
    def GetApplicationDWORD(
        self,
        rstrParentElementPath: str,
        iParentElementOccurrenceIndex: int,
        rstrDWORDValueName: str,
        pdwValue: int,
    ) -> bool: ...
    def InsertApplicationString(
        self,
        rstrParentElementPath: str,
        iParentElementOccurrenceIndex: int,
        rstrChildValueName: str,
        rstrValue: str,
    ) -> bool: ...

class dbg:  # Class
    @overload
    def __init__(self, source: str, minLevel: int) -> None: ...
    @overload
    def __init__(
        self, source: str, minLevel: int, enableConsoleOutput: bool
    ) -> None: ...

    EnableConsoleOutput: bool
    MinLevel: int
    Source: str

    def Flush(self) -> None: ...
    def BL(self, Level: int) -> None: ...
    @overload
    def PRT(self, Level: int, s: str) -> None: ...
    @overload
    def PRT(self, Level: int) -> None: ...

class fUNPACK_6890_STATE:  # Class
    def __init__(self) -> None: ...

    D2X: int
    InitTest: int
    dDX: float
    dDXold: float
    dScale: float
    dX: float
    dXold: float
    fGap: bool
    lHoleEndTime: int
    lHoleStartTime: int

class ic:  # Class
    def __init__(self) -> None: ...

    DEV_EDIT_ACTIVE: int = ...  # static # readonly
    DEV_EDIT_INACTIVE: int = ...  # static # readonly
    DEV_LOAD_ACTIVE: int = ...  # static # readonly
    DEV_LOAD_INACTIVE: int = ...  # static # readonly
    IC_ALS_7673: int = ...  # static # readonly
    IC_ALS_HS: int = ...  # static # readonly
    IC_ALS_NONE: int = ...  # static # readonly
    IC_ALS_PREP_AND_LOAD: int = ...  # static # readonly
    IC_GC_5890: int = ...  # static # readonly
    IC_GC_6850: int = ...  # static # readonly
    IC_GC_6890: int = ...  # static # readonly
    IC_GC_7810: int = ...  # static # readonly
    IC_GC_7820: int = ...  # static # readonly
    IC_GC_7890: int = ...  # static # readonly
    IC_GC_NONE: int = ...  # static # readonly
    IC_GC_OTHER: int = ...  # static # readonly
    IC_INSTALLED: int = ...  # static # readonly
    IC_MS_220: int = ...  # static # readonly
    IC_MS_240: int = ...  # static # readonly
    IC_MS_5971: int = ...  # static # readonly
    IC_MS_5972: int = ...  # static # readonly
    IC_MS_5973: int = ...  # static # readonly
    IC_MS_5974: int = ...  # static # readonly
    IC_MS_5975: int = ...  # static # readonly
    IC_MS_5976: int = ...  # static # readonly
    IC_MS_5977: int = ...  # static # readonly
    IC_MS_7000: int = ...  # static # readonly
    IC_MS_7200: int = ...  # static # readonly
    IC_MS_NONE: int = ...  # static # readonly
    IC_MS_TOF: int = ...  # static # readonly
    IC_NOT_INSTALLED: int = ...  # static # readonly
    IC_OFFLINE: int  # static
    IC_ONLINE: int  # static
    INJ_MODE_ALS: int = ...  # static # readonly
    INJ_MODE_AUTOMATIC: int = ...  # static # readonly
    INJ_MODE_AUX: int = ...  # static # readonly
    INJ_MODE_EXTERNAL: int = ...  # static # readonly
    INJ_MODE_HEADSPACE: int = ...  # static # readonly
    INJ_MODE_IMMEDIATE: int = ...  # static # readonly
    INJ_MODE_MANUAL: int = ...  # static # readonly
    INJ_MODE_MINI_THERMAL_DESORBER: int = ...  # static # readonly
    TOWER_TYPE_7683: int = ...  # static # readonly
    TOWER_TYPE_7693: int = ...  # static # readonly

    MSDCHEM_INI_FILE: str  # static # readonly

    @overload
    @staticmethod
    def GetInstrConfigString(
        InstrumentNumber: int, ItemId: Agilent.MassSpectrometry.MSDChem.InstConfigItem
    ) -> str: ...
    @overload
    @staticmethod
    def GetInstrConfigString(InstrumentNumber: int, strAdHocString: str) -> str: ...
    @staticmethod
    def GetGCIPAddress(InstPath: str, InstrumentNumber: int) -> str: ...
    @staticmethod
    def SetInstrConfig(
        InstrumentNumber: int,
        ItemId: Agilent.MassSpectrometry.MSDChem.InstConfigItem,
        strValue: str,
    ) -> int: ...
    @staticmethod
    def GetCustomerHome() -> str: ...
    @staticmethod
    def GetAvailableSources(
        i32InstrumentNumber: int, queriedSourceNames: Iterable[str]
    ) -> Dict[str, bool]: ...
    @staticmethod
    def GetInstrConfig(
        InstrumentNumber: int, ItemId: Agilent.MassSpectrometry.MSDChem.InstConfigItem
    ) -> int: ...
    @staticmethod
    def GetInstrumentPath(instrumentNumber: int) -> str: ...
    @staticmethod
    def IsConfigOnline(InstrumentNumber: int) -> bool: ...
    @staticmethod
    def GetMSIPAddress(InstrumentNumber: int) -> str: ...
    @staticmethod
    def GetApplicationConfigString(key: str) -> str: ...

    # Nested Types

    class InstrumentButtons(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        ALSDevice: Agilent.MassSpectrometry.MSDChem.ic.InstrumentButtons = (
            ...
        )  # static # readonly
        CTCDevice: Agilent.MassSpectrometry.MSDChem.ic.InstrumentButtons = (
            ...
        )  # static # readonly
        GCDevice: Agilent.MassSpectrometry.MSDChem.ic.InstrumentButtons = (
            ...
        )  # static # readonly
        HSDevice: Agilent.MassSpectrometry.MSDChem.ic.InstrumentButtons = (
            ...
        )  # static # readonly
        Inlet: Agilent.MassSpectrometry.MSDChem.ic.InstrumentButtons = (
            ...
        )  # static # readonly
        MSDevice: Agilent.MassSpectrometry.MSDChem.ic.InstrumentButtons = (
            ...
        )  # static # readonly
        MSTune: Agilent.MassSpectrometry.MSDChem.ic.InstrumentButtons = (
            ...
        )  # static # readonly
        Tools: Agilent.MassSpectrometry.MSDChem.ic.InstrumentButtons = (
            ...
        )  # static # readonly
        Vacuum: Agilent.MassSpectrometry.MSDChem.ic.InstrumentButtons = (
            ...
        )  # static # readonly

    class PressureUnits(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        Bar: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        ForelineBar: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        ForelineKiloPascal: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        ForelineMilliBar: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        ForelineMilliTorr: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        ForelinePascal: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        HighVacuumBar: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        HighVacuumKiloPascal: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        HighVacuumMilliBar: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        HighVacuumPascal: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        HighVacuumTorr: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        KiloPascal: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        MilliBar: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        MilliTorr: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        Pascal: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly
        Torr: Agilent.MassSpectrometry.MSDChem.ic.PressureUnits = (
            ...
        )  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.Renderer.Pdf

class Graphics(
    System.IDisposable, Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas
):  # Class
    def __init__(
        self,
        renderer: Agilent.MassHunter.ReportBuilder.Renderer.Pdf.Renderer,
        baseFont: iTextSharp.text.pdf.BaseFont,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...

    IgnoreFontName: bool
    PdfPTable: iTextSharp.text.pdf.PdfPTable  # readonly
    PdfTemplate: iTextSharp.text.pdf.PdfTemplate  # readonly

    def ConvertBounds(
        self, bounds: System.Drawing.RectangleF
    ) -> System.Drawing.RectangleF: ...
    def Dispose(self) -> None: ...
    def DrawImage(
        self,
        image: System.Drawing.Image,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    def GetGraphics(self) -> T: ...

class PageEvent(iTextSharp.text.pdf.IPdfPageEvent):  # Class
    def __init__(
        self,
        renderer: Agilent.MassHunter.ReportBuilder.Renderer.Pdf.Renderer,
        header: Agilent.MassHunter.ReportBuilder.Template.IHeader,
        footer: Agilent.MassHunter.ReportBuilder.Template.IFooter,
    ) -> None: ...

    Footer: Agilent.MassHunter.ReportBuilder.Template.IFooter  # readonly
    Header: Agilent.MassHunter.ReportBuilder.Template.IHeader  # readonly

    def OnEndPage(
        self, writer: iTextSharp.text.pdf.PdfWriter, document: iTextSharp.text.Document
    ) -> None: ...
    def OnGenericTag(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        document: iTextSharp.text.Document,
        rect: iTextSharp.text.Rectangle,
        text: str,
    ) -> None: ...
    def OnOpenDocument(
        self, writer: iTextSharp.text.pdf.PdfWriter, document: iTextSharp.text.Document
    ) -> None: ...
    def OnParagraph(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        document: iTextSharp.text.Document,
        paragraphPosition: float,
    ) -> None: ...
    def OnSection(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        document: iTextSharp.text.Document,
        paragraphPosition: float,
        depth: int,
        title: iTextSharp.text.Paragraph,
    ) -> None: ...
    def OnChapterEnd(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        document: iTextSharp.text.Document,
        paragraphPosition: float,
    ) -> None: ...
    def OnStartPage(
        self, writer: iTextSharp.text.pdf.PdfWriter, document: iTextSharp.text.Document
    ) -> None: ...
    def OnChapter(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        document: iTextSharp.text.Document,
        paragraphPosition: float,
        title: iTextSharp.text.Paragraph,
    ) -> None: ...
    def OnCloseDocument(
        self, writer: iTextSharp.text.pdf.PdfWriter, document: iTextSharp.text.Document
    ) -> None: ...
    def OnParagraphEnd(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        document: iTextSharp.text.Document,
        paragraphPosition: float,
    ) -> None: ...
    def OnSectionEnd(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        document: iTextSharp.text.Document,
        paragraphPosition: float,
    ) -> None: ...

class Renderer(
    System.IDisposable, Agilent.MassHunter.ReportBuilder.Engine.IReportRenderer
):  # Class
    def __init__(self, stream: System.IO.Stream) -> None: ...

    Context: Agilent.MassHunter.ReportBuilder.Engine.IReportContext
    Document: iTextSharp.text.Document  # readonly
    PdfWriter: iTextSharp.text.pdf.PdfWriter  # readonly
    UseTextAsOutlineId: bool

    def RenderImage(
        self, image: Agilent.MassHunter.ReportBuilder.Template.IImage
    ) -> None: ...
    def StartDocument(self) -> None: ...
    def PageBreak(self) -> None: ...
    def GetImage(self, path: str) -> iTextSharp.text.Image: ...
    def GetFont(
        self,
        font: Agilent.MassHunter.ReportBuilder.Template.IFont,
        color: Agilent.MassHunter.ReportBuilder.Template.IColor,
    ) -> iTextSharp.text.Font: ...
    def RenderTable(
        self, numColumns: int
    ) -> Agilent.MassHunter.ReportBuilder.Engine.ITableRenderer: ...
    def RenderGraphics(
        self, graphics: Agilent.MassHunter.ReportBuilder.Template.IGraphics
    ) -> None: ...
    @staticmethod
    def GetColor(
        color: Agilent.MassHunter.ReportBuilder.Template.IColor,
    ) -> iTextSharp.text.BaseColor: ...
    def RenderText(
        self, textbox: Agilent.MassHunter.ReportBuilder.Template.ITextbox
    ) -> None: ...
    def EndDocument(self) -> None: ...
    def SetPage(
        self, page: Agilent.MassHunter.ReportBuilder.Template.IPage
    ) -> None: ...
    def Dispose(self) -> None: ...
    @overload
    def CreateTextChunk(
        self, text: str, font: iTextSharp.text.Font, outlineLevel: Optional[int]
    ) -> iTextSharp.text.Chunk: ...
    @overload
    def CreateTextChunk(
        self,
        text: str,
        font: iTextSharp.text.Font,
        outlineId: str,
        outlineLevel: Optional[int],
    ) -> iTextSharp.text.Chunk: ...

class TableRenderer(Agilent.MassHunter.ReportBuilder.Engine.ITableRenderer):  # Class
    def SetColumnWidths(self, widths: List[float]) -> None: ...
    def EndTable(self) -> None: ...
    def SetProperties(
        self, table: Agilent.MassHunter.ReportBuilder.Template.ITable
    ) -> None: ...
    def StartHeader(self) -> None: ...
    def EndHeader(self) -> None: ...
    def AddCell(
        self, cell: Agilent.MassHunter.ReportBuilder.Template.ITableCell
    ) -> None: ...
    def EndRow(self) -> None: ...

class XpsGraphics(
    System.IDisposable, Agilent.MassHunter.ReportBuilder.Common.Engine.IGraphicsXps
):  # Class
    def __init__(
        self, renderer: Agilent.MassHunter.ReportBuilder.Renderer.Pdf.Renderer
    ) -> None: ...

    DebugMode: bool  # static # readonly

    @staticmethod
    def GetTempFileName() -> str: ...
    def Add(self, stream: System.IO.Stream) -> None: ...
    def Dispose(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Agilent.MassSpectrometry.DataAnalysis import IFXData, IPeakList, IRange

# Stubs for namespace: GenieIntegrator

class ActionCodes(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    FALSE: GenieIntegrator.ActionCodes = ...  # static # readonly
    NEGATIVE: GenieIntegrator.ActionCodes = ...  # static # readonly
    NORMAL: GenieIntegrator.ActionCodes = ...  # static # readonly
    TANSKIM: GenieIntegrator.ActionCodes = ...  # static # readonly
    TANSKIMEXP: GenieIntegrator.ActionCodes = ...  # static # readonly

class DO_PEAK(System.IComparable):  # Class
    def __init__(self) -> None: ...

    FrontShId: System.Collections.Generic.List[GenieIntegrator.DO_SHOULD]
    NrFrontShoulders: int
    NrRearShoulders: int
    RearShId: System.Collections.Generic.List[GenieIntegrator.DO_SHOULD]
    pk_info: GenieIntegrator.TGAPeakInfo

class DO_SHOULD:  # Class
    def __init__(self) -> None: ...

    height: float
    time: float

class DescriptorRecord(
    System.ICloneable,
    GenieIntegrator.IBLDescriptorRecord,
    GenieIntegrator.IMultipassDescriptorRecord,
    GenieIntegrator.IEXTDescriptorRecord,
    GenieIntegrator.IShoulderDescriptorRecord,
    GenieIntegrator.IXCPDescriptorRecord,
    GenieIntegrator.IPEAKDescriptorRecord,
    GenieIntegrator.ISLICEDescriptorRecord,
    GenieIntegrator.IHEADDescriptorRecord,
    GenieIntegrator.IEVENTDescriptorRecord,
    GenieIntegrator.IINITDescriptorRecord,
):  # Class
    def __init__(self) -> None: ...

    BL: GenieIntegrator.IBLDescriptorRecord
    EVENT: GenieIntegrator.IEVENTDescriptorRecord
    EXT: GenieIntegrator.IEXTDescriptorRecord
    FRSH: GenieIntegrator.IShoulderDescriptorRecord
    HEAD: GenieIntegrator.IHEADDescriptorRecord
    INIT: GenieIntegrator.IINITDescriptorRecord
    PEAK: GenieIntegrator.IPEAKDescriptorRecord
    RRSH: GenieIntegrator.IShoulderDescriptorRecord
    SLICE: GenieIntegrator.ISLICEDescriptorRecord
    XCP: GenieIntegrator.IXCPDescriptorRecord
    flag_peak: int
    peak_type: GenieIntegrator.DescriptorType

    area: float
    area_reject_i: float
    baseline_end: float
    baseline_start: float
    code: GenieIntegrator.TimedEventCode
    duration: float
    errors: int
    front_area_after_infl: float
    front_area_bfore_infl: float
    front_height: float
    front_inflxion_height: float
    front_inflxion_time: float
    front_r2: float
    front_ratio: float
    front_sh_time: float
    front_time: float
    half_width: float
    height: float
    initial_offset: float
    max_value: float
    min_value: float
    mismatch: float
    no_records: int
    rear_area_bfore_infl: float
    rear_height: float
    rear_inflxion_height: float
    rear_inflxion_time: float
    rear_r2: float
    rear_ratio: float
    rear_sh_time: float
    retention_time: float
    run_time: float
    slice_area_a: float
    slice_area_b: float
    slice_area_c: float
    slice_area_d: float
    slice_area_e: float
    slice_width: float
    slope: float
    start_bl_value: float
    start_right: bool
    start_time: float
    stop_bl_value: float
    symmetry: float
    time: float
    time_event: float
    time_offset: float
    value: float
    width: float

    def ResetUnionPointers(self) -> None: ...
    def Clone(self) -> Any: ...

class DescriptorType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    area_sum_peak_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    baseline_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    data_name_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    extended_peak_end_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    extended_peak_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    extended_peak_start_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    front_shoulder_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    header_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    initialize_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    man_exp_tan_peak_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    man_neg_peak_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    man_tan_peak_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    manual_peak_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    multipass_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    negative_peak_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    normal_peak_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    rear_shoulder_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    recalc_solvent_peak_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    slice_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    solvent_peak_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    tangent_skim_peak_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    timed_event_info: GenieIntegrator.DescriptorType = ...  # static # readonly
    x_cp_info: GenieIntegrator.DescriptorType = ...  # static # readonly

class FormGenieIntegratorParameters(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self,
        getAndSet: GenieIntegrator.GetAndSet,
        timedEvents: System.Collections.Generic.List[GenieIntegrator.TimedEvent],
    ) -> None: ...

    TimedEvents: System.Collections.Generic.List[GenieIntegrator.TimedEvent]  # readonly

    # Nested Types

    class GenieEventTypes(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        AreaReject: GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes = (
            ...
        )  # static # readonly
        AreaSumOff: GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes = (
            ...
        )  # static # readonly
        AreaSumOn: GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes = (
            ...
        )  # static # readonly
        BaselineAllValleysOff: (
            GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes
        ) = ...  # static # readonly
        BaselineAllValleysOn: (
            GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes
        ) = ...  # static # readonly
        BaselineBack: GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes = (
            ...
        )  # static # readonly
        BaselineHoldOff: (
            GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes
        ) = ...  # static # readonly
        BaselineHoldOn: (
            GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes
        ) = ...  # static # readonly
        BaselineNextValley: (
            GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes
        ) = ...  # static # readonly
        BaselineNow: GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes = (
            ...
        )  # static # readonly
        IntegratorOff: GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes = (
            ...
        )  # static # readonly
        IntegratorOn: GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes = (
            ...
        )  # static # readonly
        NegativePeakOff: (
            GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes
        ) = ...  # static # readonly
        NegativePeakOn: (
            GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes
        ) = ...  # static # readonly
        PeakWidth: GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes = (
            ...
        )  # static # readonly
        SolventPeakOff: (
            GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes
        ) = ...  # static # readonly
        SolventPeakOn: GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes = (
            ...
        )  # static # readonly
        TangentSkim: GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes = (
            ...
        )  # static # readonly
        Threshold: GenieIntegrator.FormGenieIntegratorParameters.GenieEventTypes = (
            ...
        )  # static # readonly

class GenieIntegrator:  # Class
    def __init__(self) -> None: ...

    AREAS: int = ...  # static # readonly
    BASELINE: int = ...  # static # readonly
    DOWNSLOPE: int = ...  # static # readonly
    DOWN_ON_SOLV_DOWN: int = ...  # static # readonly
    FRONT_SLOPE: int = ...  # static # readonly
    NULL_SET: int = ...  # static # readonly
    OFF: int = ...  # static # readonly
    REAR_SLOPE: int = ...  # static # readonly
    SLICES: int = ...  # static # readonly
    SLICES_END: int = ...  # static # readonly
    SOLVENT_DOWNSLOPE: int = ...  # static # readonly
    SOLVENT_UPSLOPE: int = ...  # static # readonly
    STARTUP: int = ...  # static # readonly
    TANGENT_WAITING: int = ...  # static # readonly
    UPSLOPE: int = ...  # static # readonly
    UP_ON_SOLV_DOWN: int = ...  # static # readonly
    aborted: int = ...  # static # readonly
    dTimeResolutionInMinutes: float = ...  # static # readonly
    distorted: int = ...  # static # readonly
    m_TimedEventList: System.Collections.Generic.List[GenieIntegrator.TimedEvent]
    m_hCardinalPointFile: System.Collections.ArrayList
    m_pGenieGetAndSet: GenieIntegrator.GetAndSet
    m_sCurrEventIndex: int
    over: int = ...  # static # readonly
    under: int = ...  # static # readonly

    def da_command_integrate_CGRAM(
        self,
        pChroObj: List[IFXData],
        pPeakList: List[IPeakList],
        p2: IRange,
        lWhichSignal: int,
    ) -> None: ...
    def IntegrateChromatograms(
        self,
        start: int,
        stop: int,
        these_objects: List[IFXData],
        theseIntegratedPeakLists: List[IPeakList],
    ) -> None: ...
    @staticmethod
    def GET_STOP_CODE(flag_bits: int) -> GenieIntegrator.flag_pk_types: ...
    def ManualIntegrateChromatogram(
        self,
        points: IFXData,
        loTimeMinutes: float,
        dStartLevel: float,
        hiTimeMinutes: float,
        dEndLevel: float,
        bDropAllValleys: bool,
    ) -> None: ...
    def gen_baseline_allocator(self, PListId: GenieIntegrator.PList) -> bool: ...
    def IntegrateChromatogram(
        self, start: int, stop: int, this_object: IFXData
    ) -> None: ...
    @staticmethod
    def GET_START_CODE(flag_bits: int) -> GenieIntegrator.flag_pk_types: ...
    @staticmethod
    def SET_IN(item: int, set: int) -> bool: ...
    def da_command_autoint(
        self,
        pChroObj: List[IFXData],
        pPeakList: List[IPeakList],
        p2: IRange,
        lWhichSignal: int,
        pct: float,
    ) -> None: ...

class GetAndSet:  # Class
    def __init__(self) -> None: ...

    area_reject: float
    area_scale_factor: float
    data_rate: float
    data_scale_factor: float
    dead_volume_time: float
    delayed_start_time: float
    detect_threshold: float
    distorted: float
    exp_pk_width: float
    overrange: float
    prebunch: float
    shoulders_enabled: bool
    solvent_slope: float
    split_solvent_v: float
    theo_plates: float
    time_offset: float
    underrange: float

class IBLDescriptorRecord(object):  # Interface
    height: float
    slope: float
    time: float

class IEVENTDescriptorRecord(object):  # Interface
    code: GenieIntegrator.TimedEventCode
    time_event: float
    value: float

class IEXTDescriptorRecord(object):  # Interface
    front_area_after_infl: float
    front_area_bfore_infl: float
    front_inflxion_height: float
    front_inflxion_time: float
    rear_area_bfore_infl: float
    rear_inflxion_height: float
    rear_inflxion_time: float

class IEventTGAPeakInfo(object):  # Interface
    code: float
    time: float
    value: float

class IHEADDescriptorRecord(object):  # Interface
    errors: int
    max_value: float
    min_value: float
    no_records: int
    run_time: float
    start_bl_value: float
    start_right: bool
    stop_bl_value: float

class IHeaderTGAPeakInfo(object):  # Interface
    errors: int
    no_records: int
    number: int
    run_time: float

class IINITDescriptorRecord(object):  # Interface
    area_reject_i: float
    initial_offset: float
    time_offset: float

class IMultipassDescriptorRecord(object):  # Interface
    front_r2: float
    front_ratio: float
    half_width: float
    mismatch: float
    rear_r2: float
    rear_ratio: float

class INormalTGAPeakInfo(object):  # Interface
    area: float
    baseline: float
    baseline_end: float
    baseline_start: float
    height: float
    level_end: float
    level_start: float
    retention_time: float
    symmetry: float
    time_end: float
    time_start: float
    width: float

class IPEAKDescriptorRecord(object):  # Interface
    area: float
    duration: float
    front_height: float
    front_time: float
    height: float
    rear_height: float
    retention_time: float

class ISLICEDescriptorRecord(object):  # Interface
    slice_area_a: float
    slice_area_b: float
    slice_area_c: float
    slice_area_d: float
    slice_area_e: float
    slice_width: float
    start_time: float

class IShoulderDescriptorRecord(object):  # Interface
    height: float
    time: float

class IShoulderTGAPeakInfo(object):  # Interface
    shoulder_height: float
    shoulder_time: float

class ISliceTGAPeakInfo(object):  # Interface
    slice_area: float
    slice_width: float
    start_time: float

class IXCPDescriptorRecord(object):  # Interface
    baseline_end: float
    baseline_start: float
    front_sh_time: float
    rear_sh_time: float
    symmetry: float
    width: float

class IntVarRecord:  # Class
    def __init__(self) -> None: ...

    _event: GenieIntegrator.TimedEvent
    averaging: bool
    backward_flag: bool
    baseline_acc: float
    baseline_acc_2: float
    baseline_acc_count: int
    baseline_flag: bool
    baseline_interval: int
    baseline_last: float
    baseline_last_when: float
    baseline_peak: GenieIntegrator.DescriptorRecord
    bunch_down: bool
    bunch_up: bool
    bunchno: int
    bunchvalue: int
    c1n: float
    c1n1: float
    c2n: float
    c2n1: float
    c3n: float
    c3n1: float
    cluster: bool
    cp_record_no: int
    cp_status: bool
    current_ticks: float
    curvature_min: float
    data_acc: float
    dn1: float
    dn2: float
    dn3: float
    dn4: float
    dn5: float
    downslope_counter: int
    dp: float
    dp1: float
    dp2: float
    dp3: float
    dp4: float
    dp_baseline: float
    dp_next_baseline: float
    dp_time: float
    dwUserData: int
    dx1: float
    dx2: float
    dx3: float
    even_odd: bool
    ext_solvent: GenieIntegrator.DescriptorRecord
    extended_peak: GenieIntegrator.DescriptorRecord
    extensio_count: int
    filter_1: bool
    filter_2: bool
    filter_3: bool
    filter_no_bunch: int
    filter_wait: int
    future_baseline_flag: bool
    future_solvent: bool
    h_errors: int
    h_start_bl_value: float
    height_at_baseline: float
    height_extrem: float
    infl_area: float
    infl_height: float
    infl_time: float
    inflection: bool
    initial_offset: float
    integ_status: GenieIntegrator.IntegStatusRecord
    integrator_state: int
    min_max: GenieIntegrator.SendParameters
    neg_curv: int
    negative_curvature: bool
    new_peak_width: float
    non_peak: GenieIntegrator.DescriptorRecord
    parameters: GenieIntegrator.IntegratorParameters
    partial_peak: GenieIntegrator.DescriptorRecord
    peak_area_acc: float
    peak_area_acc_2: float
    peak_ticks: float
    pivot_height: float
    pivot_time: float
    point: float
    pointm1: float
    pos_curv: int
    ready_for_event: bool
    real_time_extrem: float
    run_parameters: GenieIntegrator.RunTimeParameters
    s1n: float
    s1n1: float
    s2n: float
    s2n1: float
    s3n: float
    s3n1: float
    set_new_pk_width: bool
    shoulder_count: int
    shoulder_found: bool
    solvent_area_acc: float
    solvent_ds_ctr: int
    solvent_peak: GenieIntegrator.DescriptorRecord
    solvent_shoulders: bool
    start_right_flag: bool
    store_peak: bool
    store_slice: int
    time_extrem: float
    upslope_counter: int
    valley: float
    waiting_time: float

class IntegStatusRecord:  # Class
    def __init__(self) -> None: ...

    negative_peak: bool
    peak_extension_time: bool
    positive_curvature: bool
    shoulder_detect: bool

class IntegratorParameters:  # Class
    def __init__(self) -> None: ...

    i_area_reject: float
    i_area_scale_factor: float
    i_dead_volume_time: float
    i_delayed_start_time: float
    i_distorted: float
    i_double_extended: bool
    i_extended_peaks: bool
    i_external_baseline: bool
    i_external_baseline_v: float
    i_initial_data_rate: float
    i_multipass: bool
    i_overrange: float
    i_peak_width: float
    i_plates: float
    i_prebunch: float
    i_shoulders: bool
    i_solvent_slope: float
    i_split_solvent: float
    i_threshold: float
    i_time_offset: float
    i_underrange: float
    i_variwidth: bool

class PList(
    List[Any],
    Iterable[Any],
    System.Collections.ArrayList,
    Sequence[Any],
    System.ICloneable,
):  # Class
    def __init__(self) -> None: ...

class RunTimeParameters:  # Class
    def __init__(self) -> None: ...

    auto_peak_width_disable: bool
    baseline_reset_valley: bool
    baseline_rst_all_valleys: bool
    broadening: bool
    dead_volume_time: float
    delayed_start_time: float
    drop: bool
    drop_valley: bool
    extended_peaks: bool
    fire_value: float
    hold_baseline: bool
    need_int_ranging: bool
    negative_peaks: bool
    peak_broadening_rate: float
    peak_width: float
    rflag: int
    set_peak_width: bool
    shoulders_as_peaks: bool
    slice_width: float
    solvent_slope: float
    split_solvent: float
    tangent_skim: bool
    th1: float
    th2: float
    threshold: float
    time_offset: float

class SendParameters:  # Class
    def __init__(self) -> None: ...

    max_value: float
    min_value: float

class SortEventTimeAscendingHelper(System.Collections.IComparer):  # Class
    def __init__(self) -> None: ...
    def Compare(self, x: Any, y: Any) -> int: ...

class TGAPeakInfo(
    GenieIntegrator.ISliceTGAPeakInfo,
    GenieIntegrator.IShoulderTGAPeakInfo,
    GenieIntegrator.IEventTGAPeakInfo,
    GenieIntegrator.IHeaderTGAPeakInfo,
    GenieIntegrator.INormalTGAPeakInfo,
):  # Class
    def __init__(self) -> None: ...

    T_EVENT: GenieIntegrator.IEventTGAPeakInfo
    T_FRSH: GenieIntegrator.IShoulderTGAPeakInfo
    T_HEAD: GenieIntegrator.IHeaderTGAPeakInfo
    T_PEAK: GenieIntegrator.INormalTGAPeakInfo
    T_RRSH: GenieIntegrator.IShoulderTGAPeakInfo
    T_SLICE: GenieIntegrator.ISliceTGAPeakInfo
    flag_peak: int
    peak_type: GenieIntegrator.DescriptorType

    area: float
    baseline: float
    baseline_end: float
    baseline_start: float
    code: float
    errors: int
    height: float
    level_end: float
    level_start: float
    no_records: int
    number: int
    retention_time: float
    run_time: float
    shoulder_height: float
    shoulder_time: float
    slice_area: float
    slice_width: float
    start_time: float
    symmetry: float
    time: float
    time_end: float
    time_start: float
    value: float
    width: float

class TimedEvent:  # Class
    def __init__(self) -> None: ...

    event_code: GenieIntegrator.TimedEventCode
    time: float
    value: float

    def RequiresValue(self) -> bool: ...

class TimedEventCode(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    ECALLVALLEYS: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECAREAS: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECARM: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECBACKWARD: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECBASELINE: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECDISABLE: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECEND: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECFRONT: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECHOLD: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECIMMEDIATE: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECNEGATIVE: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECOFFSET: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECREJECT: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECSHOULDERS: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECSLICES: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECSP: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECTANGENT: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECTHRESHOLD: GenieIntegrator.TimedEventCode = ...  # static # readonly
    ECWIDTH: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECALLVALLEYS: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECAREAS: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECARM: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECBACKWARD: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECBASELINE: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECDISABLE: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECEND: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECFRONT: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECHOLD: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECNEGATIVE: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECREJECT: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECSHOULDERS: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECSLICES: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECSP: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECTANGENT: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECTHRESHOLD: GenieIntegrator.TimedEventCode = ...  # static # readonly
    MECWIDTH: GenieIntegrator.TimedEventCode = ...  # static # readonly

class al_time_parameters:  # Class
    def __init__(self) -> None: ...

    area_reject: float
    areas: bool
    fix_backwards_flag: bool
    negative_peaks: bool
    penetration: bool
    slices: bool
    tangent_skim: bool

class al_vars:  # Class
    def __init__(self) -> None: ...

    NextPkId: GenieIntegrator.DO_PEAK
    NrFrontShoulders: int
    NrRearShoulders: int
    PListId: GenieIntegrator.PList
    al_baseline: float
    al_parameters: GenieIntegrator.al_time_parameters
    area_adjusted: float
    area_adjustment: float
    bl_slope: float
    bl_time: float
    bl_value: float
    cp_status: bool
    duration: float
    end_height: float
    extend_follows: bool
    fix_b: float
    fix_backwards_offset: float
    fix_later: float
    front_height: float
    front_time: float
    height_adjusted: float
    height_factor: float
    multipass_found: bool
    multipassrecord: GenieIntegrator.TGAPeakInfo
    no_more_room: bool
    nr_records: int
    offset: float
    offset_time: float
    offset_time_2: float
    parameters: GenieIntegrator.IntegratorParameters
    peak: GenieIntegrator.DescriptorRecord
    peakid: GenieIntegrator.DO_PEAK
    proc_write_status: bool
    processed_peak: GenieIntegrator.TGAPeakInfo
    rear_height: float
    rear_time: float
    retention_time: float
    solvent_time: float
    this_cp_rec_no: int
    time_baseline: float
    time_factor: float
    v_offset: float
    v_offset_2: float
    v_slope: float
    v_time: float

class flag_pk_types(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    baseline_pk: GenieIntegrator.flag_pk_types = ...  # static # readonly
    force_pk: GenieIntegrator.flag_pk_types = ...  # static # readonly
    horizontal_pk: GenieIntegrator.flag_pk_types = ...  # static # readonly
    manual_pk: GenieIntegrator.flag_pk_types = ...  # static # readonly
    penetration_pk: GenieIntegrator.flag_pk_types = ...  # static # readonly
    valley_pk: GenieIntegrator.flag_pk_types = ...  # static # readonly

class run_parameter_flags(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    auto_solvent_disable: GenieIntegrator.run_parameter_flags = ...  # static # readonly
    fire_on_inflection: GenieIntegrator.run_parameter_flags = ...  # static # readonly
    fire_on_top: GenieIntegrator.run_parameter_flags = ...  # static # readonly
    fire_on_valley: GenieIntegrator.run_parameter_flags = ...  # static # readonly
    fire_on_value: GenieIntegrator.run_parameter_flags = ...  # static # readonly
    front_tangent: GenieIntegrator.run_parameter_flags = ...  # static # readonly
    integrator_off: GenieIntegrator.run_parameter_flags = ...  # static # readonly
    shoulders: GenieIntegrator.run_parameter_flags = ...  # static # readonly

class tgcresponseerrors(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    adoverrange: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    adproblem: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    analysisaborted: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    cardpoints_gt_max: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    controleventsaborted: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    endnotonbaseline: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    error7: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    excessnegativeinput: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    integoridentaborted: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    nopeaksintegrated: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    noreferencepeakfound: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    nostandardpeakfound: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    nosummedpeaks: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    numberofpeaks_gt_max: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    readingsmissed: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
    runaborted: GenieIntegrator.tgcresponseerrors = ...  # static # readonly
